#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotApplyorderStatusSyncModel(object):

    def __init__(self):
        self._apply_order_status = None
        self._asset_apply_order_id = None

    @property
    def apply_order_status(self):
        return self._apply_order_status

    @apply_order_status.setter
    def apply_order_status(self, value):
        self._apply_order_status = value
    @property
    def asset_apply_order_id(self):
        return self._asset_apply_order_id

    @asset_apply_order_id.setter
    def asset_apply_order_id(self, value):
        self._asset_apply_order_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_order_status:
            if hasattr(self.apply_order_status, 'to_alipay_dict'):
                params['apply_order_status'] = self.apply_order_status.to_alipay_dict()
            else:
                params['apply_order_status'] = self.apply_order_status
        if self.asset_apply_order_id:
            if hasattr(self.asset_apply_order_id, 'to_alipay_dict'):
                params['asset_apply_order_id'] = self.asset_apply_order_id.to_alipay_dict()
            else:
                params['asset_apply_order_id'] = self.asset_apply_order_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotApplyorderStatusSyncModel()
        if 'apply_order_status' in d:
            o.apply_order_status = d['apply_order_status']
        if 'asset_apply_order_id' in d:
            o.asset_apply_order_id = d['asset_apply_order_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ApeRecItem import ApeRecItem


class AlipayDigitalopUcdpApeitemQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDigitalopUcdpApeitemQueryResponse, self).__init__()
        self._items = None
        self._trace_id = None

    @property
    def items(self):
        return self._items

    @items.setter
    def items(self, value):
        if isinstance(value, list):
            self._items = list()
            for i in value:
                if isinstance(i, ApeRecItem):
                    self._items.append(i)
                else:
                    self._items.append(ApeRecItem.from_alipay_dict(i))
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayDigitalopUcdpApeitemQueryResponse, self).parse_response_content(response_content)
        if 'items' in response:
            self.items = response['items']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsOption(object):

    def __init__(self):
        self._coverage = None
        self._coverage_text = None

    @property
    def coverage(self):
        return self._coverage

    @coverage.setter
    def coverage(self, value):
        self._coverage = value
    @property
    def coverage_text(self):
        return self._coverage_text

    @coverage_text.setter
    def coverage_text(self, value):
        self._coverage_text = value


    def to_alipay_dict(self):
        params = dict()
        if self.coverage:
            if hasattr(self.coverage, 'to_alipay_dict'):
                params['coverage'] = self.coverage.to_alipay_dict()
            else:
                params['coverage'] = self.coverage
        if self.coverage_text:
            if hasattr(self.coverage_text, 'to_alipay_dict'):
                params['coverage_text'] = self.coverage_text.to_alipay_dict()
            else:
                params['coverage_text'] = self.coverage_text
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsOption()
        if 'coverage' in d:
            o.coverage = d['coverage']
        if 'coverage_text' in d:
            o.coverage_text = d['coverage_text']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemPrizeInfo(object):

    def __init__(self):
        self._item_can_exchange = None
        self._item_code = None
        self._item_icon_url = None
        self._item_name = None
        self._item_price = None
        self._point_amount = None

    @property
    def item_can_exchange(self):
        return self._item_can_exchange

    @item_can_exchange.setter
    def item_can_exchange(self, value):
        self._item_can_exchange = value
    @property
    def item_code(self):
        return self._item_code

    @item_code.setter
    def item_code(self, value):
        self._item_code = value
    @property
    def item_icon_url(self):
        return self._item_icon_url

    @item_icon_url.setter
    def item_icon_url(self, value):
        self._item_icon_url = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def item_price(self):
        return self._item_price

    @item_price.setter
    def item_price(self, value):
        self._item_price = value
    @property
    def point_amount(self):
        return self._point_amount

    @point_amount.setter
    def point_amount(self, value):
        self._point_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_can_exchange:
            if hasattr(self.item_can_exchange, 'to_alipay_dict'):
                params['item_can_exchange'] = self.item_can_exchange.to_alipay_dict()
            else:
                params['item_can_exchange'] = self.item_can_exchange
        if self.item_code:
            if hasattr(self.item_code, 'to_alipay_dict'):
                params['item_code'] = self.item_code.to_alipay_dict()
            else:
                params['item_code'] = self.item_code
        if self.item_icon_url:
            if hasattr(self.item_icon_url, 'to_alipay_dict'):
                params['item_icon_url'] = self.item_icon_url.to_alipay_dict()
            else:
                params['item_icon_url'] = self.item_icon_url
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.item_price:
            if hasattr(self.item_price, 'to_alipay_dict'):
                params['item_price'] = self.item_price.to_alipay_dict()
            else:
                params['item_price'] = self.item_price
        if self.point_amount:
            if hasattr(self.point_amount, 'to_alipay_dict'):
                params['point_amount'] = self.point_amount.to_alipay_dict()
            else:
                params['point_amount'] = self.point_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemPrizeInfo()
        if 'item_can_exchange' in d:
            o.item_can_exchange = d['item_can_exchange']
        if 'item_code' in d:
            o.item_code = d['item_code']
        if 'item_icon_url' in d:
            o.item_icon_url = d['item_icon_url']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'item_price' in d:
            o.item_price = d['item_price']
        if 'point_amount' in d:
            o.point_amount = d['point_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMsaasMediarecogVoiceMediaaudioUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMsaasMediarecogVoiceMediaaudioUploadResponse, self).__init__()
        self._extinfo_a = None
        self._extinfo_b = None
        self._result_memo = None
        self._result_status = None

    @property
    def extinfo_a(self):
        return self._extinfo_a

    @extinfo_a.setter
    def extinfo_a(self, value):
        self._extinfo_a = value
    @property
    def extinfo_b(self):
        return self._extinfo_b

    @extinfo_b.setter
    def extinfo_b(self, value):
        self._extinfo_b = value
    @property
    def result_memo(self):
        return self._result_memo

    @result_memo.setter
    def result_memo(self, value):
        self._result_memo = value
    @property
    def result_status(self):
        return self._result_status

    @result_status.setter
    def result_status(self, value):
        self._result_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayMsaasMediarecogVoiceMediaaudioUploadResponse, self).parse_response_content(response_content)
        if 'extinfo_a' in response:
            self.extinfo_a = response['extinfo_a']
        if 'extinfo_b' in response:
            self.extinfo_b = response['extinfo_b']
        if 'result_memo' in response:
            self.result_memo = response['result_memo']
        if 'result_status' in response:
            self.result_status = response['result_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceEducateCompetitionErrorresultNotifyModel(object):

    def __init__(self):
        self._error_code = None
        self._error_msg = None
        self._source_id = None

    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def source_id(self):
        return self._source_id

    @source_id.setter
    def source_id(self, value):
        self._source_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.error_code:
            if hasattr(self.error_code, 'to_alipay_dict'):
                params['error_code'] = self.error_code.to_alipay_dict()
            else:
                params['error_code'] = self.error_code
        if self.error_msg:
            if hasattr(self.error_msg, 'to_alipay_dict'):
                params['error_msg'] = self.error_msg.to_alipay_dict()
            else:
                params['error_msg'] = self.error_msg
        if self.source_id:
            if hasattr(self.source_id, 'to_alipay_dict'):
                params['source_id'] = self.source_id.to_alipay_dict()
            else:
                params['source_id'] = self.source_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceEducateCompetitionErrorresultNotifyModel()
        if 'error_code' in d:
            o.error_code = d['error_code']
        if 'error_msg' in d:
            o.error_msg = d['error_msg']
        if 'source_id' in d:
            o.source_id = d['source_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniDataVisittrendQueryModel(object):

    def __init__(self):
        self._time_unit = None

    @property
    def time_unit(self):
        return self._time_unit

    @time_unit.setter
    def time_unit(self, value):
        self._time_unit = value


    def to_alipay_dict(self):
        params = dict()
        if self.time_unit:
            if hasattr(self.time_unit, 'to_alipay_dict'):
                params['time_unit'] = self.time_unit.to_alipay_dict()
            else:
                params['time_unit'] = self.time_unit
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniDataVisittrendQueryModel()
        if 'time_unit' in d:
            o.time_unit = d['time_unit']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoCplifeRepairStatusUpdateModel(object):

    def __init__(self):
        self._biz_details = None
        self._biz_state = None
        self._req_id = None

    @property
    def biz_details(self):
        return self._biz_details

    @biz_details.setter
    def biz_details(self, value):
        self._biz_details = value
    @property
    def biz_state(self):
        return self._biz_state

    @biz_state.setter
    def biz_state(self, value):
        self._biz_state = value
    @property
    def req_id(self):
        return self._req_id

    @req_id.setter
    def req_id(self, value):
        self._req_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_details:
            if hasattr(self.biz_details, 'to_alipay_dict'):
                params['biz_details'] = self.biz_details.to_alipay_dict()
            else:
                params['biz_details'] = self.biz_details
        if self.biz_state:
            if hasattr(self.biz_state, 'to_alipay_dict'):
                params['biz_state'] = self.biz_state.to_alipay_dict()
            else:
                params['biz_state'] = self.biz_state
        if self.req_id:
            if hasattr(self.req_id, 'to_alipay_dict'):
                params['req_id'] = self.req_id.to_alipay_dict()
            else:
                params['req_id'] = self.req_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoCplifeRepairStatusUpdateModel()
        if 'biz_details' in d:
            o.biz_details = d['biz_details']
        if 'biz_state' in d:
            o.biz_state = d['biz_state']
        if 'req_id' in d:
            o.req_id = d['req_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MoreInfoDTO(object):

    def __init__(self):
        self._descs = None
        self._params = None
        self._title = None
        self._url = None

    @property
    def descs(self):
        return self._descs

    @descs.setter
    def descs(self, value):
        if isinstance(value, list):
            self._descs = list()
            for i in value:
                self._descs.append(i)
    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, value):
        self._params = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def url(self):
        return self._url

    @url.setter
    def url(self, value):
        self._url = value


    def to_alipay_dict(self):
        params = dict()
        if self.descs:
            if isinstance(self.descs, list):
                for i in range(0, len(self.descs)):
                    element = self.descs[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.descs[i] = element.to_alipay_dict()
            if hasattr(self.descs, 'to_alipay_dict'):
                params['descs'] = self.descs.to_alipay_dict()
            else:
                params['descs'] = self.descs
        if self.params:
            if hasattr(self.params, 'to_alipay_dict'):
                params['params'] = self.params.to_alipay_dict()
            else:
                params['params'] = self.params
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.url:
            if hasattr(self.url, 'to_alipay_dict'):
                params['url'] = self.url.to_alipay_dict()
            else:
                params['url'] = self.url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MoreInfoDTO()
        if 'descs' in d:
            o.descs = d['descs']
        if 'params' in d:
            o.params = d['params']
        if 'title' in d:
            o.title = d['title']
        if 'url' in d:
            o.url = d['url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DeviceParams(object):

    def __init__(self):
        self._device_id = None
        self._device_name = None
        self._device_type = None

    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def device_name(self):
        return self._device_name

    @device_name.setter
    def device_name(self, value):
        self._device_name = value
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.device_name:
            if hasattr(self.device_name, 'to_alipay_dict'):
                params['device_name'] = self.device_name.to_alipay_dict()
            else:
                params['device_name'] = self.device_name
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeviceParams()
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'device_name' in d:
            o.device_name = d['device_name']
        if 'device_type' in d:
            o.device_type = d['device_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BenefitAmountInfo import BenefitAmountInfo
from alipay.aop.api.domain.BenefitDateInfo import BenefitDateInfo
from alipay.aop.api.domain.BenefitDisplayInfo import BenefitDisplayInfo
from alipay.aop.api.domain.BenefitSource import BenefitSource


class BenefitDetailInfo(object):

    def __init__(self):
        self._benefit_amount_info = None
        self._benefit_date_info = None
        self._benefit_display_info = None
        self._benefit_id = None
        self._benefit_operation_id = None
        self._benefit_operation_time = None
        self._benefit_source = None
        self._benefit_status = None
        self._benefit_type = None
        self._customer_id = None

    @property
    def benefit_amount_info(self):
        return self._benefit_amount_info

    @benefit_amount_info.setter
    def benefit_amount_info(self, value):
        if isinstance(value, BenefitAmountInfo):
            self._benefit_amount_info = value
        else:
            self._benefit_amount_info = BenefitAmountInfo.from_alipay_dict(value)
    @property
    def benefit_date_info(self):
        return self._benefit_date_info

    @benefit_date_info.setter
    def benefit_date_info(self, value):
        if isinstance(value, BenefitDateInfo):
            self._benefit_date_info = value
        else:
            self._benefit_date_info = BenefitDateInfo.from_alipay_dict(value)
    @property
    def benefit_display_info(self):
        return self._benefit_display_info

    @benefit_display_info.setter
    def benefit_display_info(self, value):
        if isinstance(value, BenefitDisplayInfo):
            self._benefit_display_info = value
        else:
            self._benefit_display_info = BenefitDisplayInfo.from_alipay_dict(value)
    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def benefit_operation_id(self):
        return self._benefit_operation_id

    @benefit_operation_id.setter
    def benefit_operation_id(self, value):
        self._benefit_operation_id = value
    @property
    def benefit_operation_time(self):
        return self._benefit_operation_time

    @benefit_operation_time.setter
    def benefit_operation_time(self, value):
        self._benefit_operation_time = value
    @property
    def benefit_source(self):
        return self._benefit_source

    @benefit_source.setter
    def benefit_source(self, value):
        if isinstance(value, BenefitSource):
            self._benefit_source = value
        else:
            self._benefit_source = BenefitSource.from_alipay_dict(value)
    @property
    def benefit_status(self):
        return self._benefit_status

    @benefit_status.setter
    def benefit_status(self, value):
        self._benefit_status = value
    @property
    def benefit_type(self):
        return self._benefit_type

    @benefit_type.setter
    def benefit_type(self, value):
        self._benefit_type = value
    @property
    def customer_id(self):
        return self._customer_id

    @customer_id.setter
    def customer_id(self, value):
        self._customer_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_amount_info:
            if hasattr(self.benefit_amount_info, 'to_alipay_dict'):
                params['benefit_amount_info'] = self.benefit_amount_info.to_alipay_dict()
            else:
                params['benefit_amount_info'] = self.benefit_amount_info
        if self.benefit_date_info:
            if hasattr(self.benefit_date_info, 'to_alipay_dict'):
                params['benefit_date_info'] = self.benefit_date_info.to_alipay_dict()
            else:
                params['benefit_date_info'] = self.benefit_date_info
        if self.benefit_display_info:
            if hasattr(self.benefit_display_info, 'to_alipay_dict'):
                params['benefit_display_info'] = self.benefit_display_info.to_alipay_dict()
            else:
                params['benefit_display_info'] = self.benefit_display_info
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.benefit_operation_id:
            if hasattr(self.benefit_operation_id, 'to_alipay_dict'):
                params['benefit_operation_id'] = self.benefit_operation_id.to_alipay_dict()
            else:
                params['benefit_operation_id'] = self.benefit_operation_id
        if self.benefit_operation_time:
            if hasattr(self.benefit_operation_time, 'to_alipay_dict'):
                params['benefit_operation_time'] = self.benefit_operation_time.to_alipay_dict()
            else:
                params['benefit_operation_time'] = self.benefit_operation_time
        if self.benefit_source:
            if hasattr(self.benefit_source, 'to_alipay_dict'):
                params['benefit_source'] = self.benefit_source.to_alipay_dict()
            else:
                params['benefit_source'] = self.benefit_source
        if self.benefit_status:
            if hasattr(self.benefit_status, 'to_alipay_dict'):
                params['benefit_status'] = self.benefit_status.to_alipay_dict()
            else:
                params['benefit_status'] = self.benefit_status
        if self.benefit_type:
            if hasattr(self.benefit_type, 'to_alipay_dict'):
                params['benefit_type'] = self.benefit_type.to_alipay_dict()
            else:
                params['benefit_type'] = self.benefit_type
        if self.customer_id:
            if hasattr(self.customer_id, 'to_alipay_dict'):
                params['customer_id'] = self.customer_id.to_alipay_dict()
            else:
                params['customer_id'] = self.customer_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BenefitDetailInfo()
        if 'benefit_amount_info' in d:
            o.benefit_amount_info = d['benefit_amount_info']
        if 'benefit_date_info' in d:
            o.benefit_date_info = d['benefit_date_info']
        if 'benefit_display_info' in d:
            o.benefit_display_info = d['benefit_display_info']
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'benefit_operation_id' in d:
            o.benefit_operation_id = d['benefit_operation_id']
        if 'benefit_operation_time' in d:
            o.benefit_operation_time = d['benefit_operation_time']
        if 'benefit_source' in d:
            o.benefit_source = d['benefit_source']
        if 'benefit_status' in d:
            o.benefit_status = d['benefit_status']
        if 'benefit_type' in d:
            o.benefit_type = d['benefit_type']
        if 'customer_id' in d:
            o.customer_id = d['customer_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MarketingAuthorizedData import MarketingAuthorizedData
from alipay.aop.api.domain.MarketingPartner import MarketingPartner


class AlipayMarketingPartnershipsStopModel(object):

    def __init__(self):
        self._authorized_data = None
        self._partner = None

    @property
    def authorized_data(self):
        return self._authorized_data

    @authorized_data.setter
    def authorized_data(self, value):
        if isinstance(value, MarketingAuthorizedData):
            self._authorized_data = value
        else:
            self._authorized_data = MarketingAuthorizedData.from_alipay_dict(value)
    @property
    def partner(self):
        return self._partner

    @partner.setter
    def partner(self, value):
        if isinstance(value, MarketingPartner):
            self._partner = value
        else:
            self._partner = MarketingPartner.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.authorized_data:
            if hasattr(self.authorized_data, 'to_alipay_dict'):
                params['authorized_data'] = self.authorized_data.to_alipay_dict()
            else:
                params['authorized_data'] = self.authorized_data
        if self.partner:
            if hasattr(self.partner, 'to_alipay_dict'):
                params['partner'] = self.partner.to_alipay_dict()
            else:
                params['partner'] = self.partner
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingPartnershipsStopModel()
        if 'authorized_data' in d:
            o.authorized_data = d['authorized_data']
        if 'partner' in d:
            o.partner = d['partner']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOfflineMarketShopModifyModel(object):

    def __init__(self):
        self._address = None
        self._audit_images = None
        self._auth_letter = None
        self._avg_price = None
        self._biz_version = None
        self._box = None
        self._branch_shop_name = None
        self._brand_logo = None
        self._brand_name = None
        self._business_certificate = None
        self._business_certificate_expires = None
        self._business_time = None
        self._category_id = None
        self._city_code = None
        self._contact_number = None
        self._district_code = None
        self._implement_id = None
        self._is_operating_online = None
        self._is_show = None
        self._latitude = None
        self._licence = None
        self._licence_code = None
        self._licence_expires = None
        self._licence_name = None
        self._longitude = None
        self._main_image = None
        self._main_shop_name = None
        self._no_smoking = None
        self._notify_mobile = None
        self._online_image = None
        self._online_url = None
        self._op_id = None
        self._op_role = None
        self._operate_notify_url = None
        self._other_authorization = None
        self._parking = None
        self._partner_id = None
        self._pay_type = None
        self._province_code = None
        self._request_id = None
        self._shop_id = None
        self._store_id = None
        self._value_added = None
        self._version = None
        self._wifi = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def audit_images(self):
        return self._audit_images

    @audit_images.setter
    def audit_images(self, value):
        self._audit_images = value
    @property
    def auth_letter(self):
        return self._auth_letter

    @auth_letter.setter
    def auth_letter(self, value):
        self._auth_letter = value
    @property
    def avg_price(self):
        return self._avg_price

    @avg_price.setter
    def avg_price(self, value):
        self._avg_price = value
    @property
    def biz_version(self):
        return self._biz_version

    @biz_version.setter
    def biz_version(self, value):
        self._biz_version = value
    @property
    def box(self):
        return self._box

    @box.setter
    def box(self, value):
        self._box = value
    @property
    def branch_shop_name(self):
        return self._branch_shop_name

    @branch_shop_name.setter
    def branch_shop_name(self, value):
        self._branch_shop_name = value
    @property
    def brand_logo(self):
        return self._brand_logo

    @brand_logo.setter
    def brand_logo(self, value):
        self._brand_logo = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def business_certificate(self):
        return self._business_certificate

    @business_certificate.setter
    def business_certificate(self, value):
        self._business_certificate = value
    @property
    def business_certificate_expires(self):
        return self._business_certificate_expires

    @business_certificate_expires.setter
    def business_certificate_expires(self, value):
        self._business_certificate_expires = value
    @property
    def business_time(self):
        return self._business_time

    @business_time.setter
    def business_time(self, value):
        self._business_time = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def contact_number(self):
        return self._contact_number

    @contact_number.setter
    def contact_number(self, value):
        self._contact_number = value
    @property
    def district_code(self):
        return self._district_code

    @district_code.setter
    def district_code(self, value):
        self._district_code = value
    @property
    def implement_id(self):
        return self._implement_id

    @implement_id.setter
    def implement_id(self, value):
        self._implement_id = value
    @property
    def is_operating_online(self):
        return self._is_operating_online

    @is_operating_online.setter
    def is_operating_online(self, value):
        self._is_operating_online = value
    @property
    def is_show(self):
        return self._is_show

    @is_show.setter
    def is_show(self, value):
        self._is_show = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def licence(self):
        return self._licence

    @licence.setter
    def licence(self, value):
        self._licence = value
    @property
    def licence_code(self):
        return self._licence_code

    @licence_code.setter
    def licence_code(self, value):
        self._licence_code = value
    @property
    def licence_expires(self):
        return self._licence_expires

    @licence_expires.setter
    def licence_expires(self, value):
        self._licence_expires = value
    @property
    def licence_name(self):
        return self._licence_name

    @licence_name.setter
    def licence_name(self, value):
        self._licence_name = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def main_image(self):
        return self._main_image

    @main_image.setter
    def main_image(self, value):
        self._main_image = value
    @property
    def main_shop_name(self):
        return self._main_shop_name

    @main_shop_name.setter
    def main_shop_name(self, value):
        self._main_shop_name = value
    @property
    def no_smoking(self):
        return self._no_smoking

    @no_smoking.setter
    def no_smoking(self, value):
        self._no_smoking = value
    @property
    def notify_mobile(self):
        return self._notify_mobile

    @notify_mobile.setter
    def notify_mobile(self, value):
        self._notify_mobile = value
    @property
    def online_image(self):
        return self._online_image

    @online_image.setter
    def online_image(self, value):
        self._online_image = value
    @property
    def online_url(self):
        return self._online_url

    @online_url.setter
    def online_url(self, value):
        self._online_url = value
    @property
    def op_id(self):
        return self._op_id

    @op_id.setter
    def op_id(self, value):
        self._op_id = value
    @property
    def op_role(self):
        return self._op_role

    @op_role.setter
    def op_role(self, value):
        self._op_role = value
    @property
    def operate_notify_url(self):
        return self._operate_notify_url

    @operate_notify_url.setter
    def operate_notify_url(self, value):
        self._operate_notify_url = value
    @property
    def other_authorization(self):
        return self._other_authorization

    @other_authorization.setter
    def other_authorization(self, value):
        self._other_authorization = value
    @property
    def parking(self):
        return self._parking

    @parking.setter
    def parking(self, value):
        self._parking = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def pay_type(self):
        return self._pay_type

    @pay_type.setter
    def pay_type(self, value):
        self._pay_type = value
    @property
    def province_code(self):
        return self._province_code

    @province_code.setter
    def province_code(self, value):
        self._province_code = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value
    @property
    def value_added(self):
        return self._value_added

    @value_added.setter
    def value_added(self, value):
        self._value_added = value
    @property
    def version(self):
        return self._version

    @version.setter
    def version(self, value):
        self._version = value
    @property
    def wifi(self):
        return self._wifi

    @wifi.setter
    def wifi(self, value):
        self._wifi = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.audit_images:
            if hasattr(self.audit_images, 'to_alipay_dict'):
                params['audit_images'] = self.audit_images.to_alipay_dict()
            else:
                params['audit_images'] = self.audit_images
        if self.auth_letter:
            if hasattr(self.auth_letter, 'to_alipay_dict'):
                params['auth_letter'] = self.auth_letter.to_alipay_dict()
            else:
                params['auth_letter'] = self.auth_letter
        if self.avg_price:
            if hasattr(self.avg_price, 'to_alipay_dict'):
                params['avg_price'] = self.avg_price.to_alipay_dict()
            else:
                params['avg_price'] = self.avg_price
        if self.biz_version:
            if hasattr(self.biz_version, 'to_alipay_dict'):
                params['biz_version'] = self.biz_version.to_alipay_dict()
            else:
                params['biz_version'] = self.biz_version
        if self.box:
            if hasattr(self.box, 'to_alipay_dict'):
                params['box'] = self.box.to_alipay_dict()
            else:
                params['box'] = self.box
        if self.branch_shop_name:
            if hasattr(self.branch_shop_name, 'to_alipay_dict'):
                params['branch_shop_name'] = self.branch_shop_name.to_alipay_dict()
            else:
                params['branch_shop_name'] = self.branch_shop_name
        if self.brand_logo:
            if hasattr(self.brand_logo, 'to_alipay_dict'):
                params['brand_logo'] = self.brand_logo.to_alipay_dict()
            else:
                params['brand_logo'] = self.brand_logo
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.business_certificate:
            if hasattr(self.business_certificate, 'to_alipay_dict'):
                params['business_certificate'] = self.business_certificate.to_alipay_dict()
            else:
                params['business_certificate'] = self.business_certificate
        if self.business_certificate_expires:
            if hasattr(self.business_certificate_expires, 'to_alipay_dict'):
                params['business_certificate_expires'] = self.business_certificate_expires.to_alipay_dict()
            else:
                params['business_certificate_expires'] = self.business_certificate_expires
        if self.business_time:
            if hasattr(self.business_time, 'to_alipay_dict'):
                params['business_time'] = self.business_time.to_alipay_dict()
            else:
                params['business_time'] = self.business_time
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.contact_number:
            if hasattr(self.contact_number, 'to_alipay_dict'):
                params['contact_number'] = self.contact_number.to_alipay_dict()
            else:
                params['contact_number'] = self.contact_number
        if self.district_code:
            if hasattr(self.district_code, 'to_alipay_dict'):
                params['district_code'] = self.district_code.to_alipay_dict()
            else:
                params['district_code'] = self.district_code
        if self.implement_id:
            if hasattr(self.implement_id, 'to_alipay_dict'):
                params['implement_id'] = self.implement_id.to_alipay_dict()
            else:
                params['implement_id'] = self.implement_id
        if self.is_operating_online:
            if hasattr(self.is_operating_online, 'to_alipay_dict'):
                params['is_operating_online'] = self.is_operating_online.to_alipay_dict()
            else:
                params['is_operating_online'] = self.is_operating_online
        if self.is_show:
            if hasattr(self.is_show, 'to_alipay_dict'):
                params['is_show'] = self.is_show.to_alipay_dict()
            else:
                params['is_show'] = self.is_show
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.licence:
            if hasattr(self.licence, 'to_alipay_dict'):
                params['licence'] = self.licence.to_alipay_dict()
            else:
                params['licence'] = self.licence
        if self.licence_code:
            if hasattr(self.licence_code, 'to_alipay_dict'):
                params['licence_code'] = self.licence_code.to_alipay_dict()
            else:
                params['licence_code'] = self.licence_code
        if self.licence_expires:
            if hasattr(self.licence_expires, 'to_alipay_dict'):
                params['licence_expires'] = self.licence_expires.to_alipay_dict()
            else:
                params['licence_expires'] = self.licence_expires
        if self.licence_name:
            if hasattr(self.licence_name, 'to_alipay_dict'):
                params['licence_name'] = self.licence_name.to_alipay_dict()
            else:
                params['licence_name'] = self.licence_name
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.main_image:
            if hasattr(self.main_image, 'to_alipay_dict'):
                params['main_image'] = self.main_image.to_alipay_dict()
            else:
                params['main_image'] = self.main_image
        if self.main_shop_name:
            if hasattr(self.main_shop_name, 'to_alipay_dict'):
                params['main_shop_name'] = self.main_shop_name.to_alipay_dict()
            else:
                params['main_shop_name'] = self.main_shop_name
        if self.no_smoking:
            if hasattr(self.no_smoking, 'to_alipay_dict'):
                params['no_smoking'] = self.no_smoking.to_alipay_dict()
            else:
                params['no_smoking'] = self.no_smoking
        if self.notify_mobile:
            if hasattr(self.notify_mobile, 'to_alipay_dict'):
                params['notify_mobile'] = self.notify_mobile.to_alipay_dict()
            else:
                params['notify_mobile'] = self.notify_mobile
        if self.online_image:
            if hasattr(self.online_image, 'to_alipay_dict'):
                params['online_image'] = self.online_image.to_alipay_dict()
            else:
                params['online_image'] = self.online_image
        if self.online_url:
            if hasattr(self.online_url, 'to_alipay_dict'):
                params['online_url'] = self.online_url.to_alipay_dict()
            else:
                params['online_url'] = self.online_url
        if self.op_id:
            if hasattr(self.op_id, 'to_alipay_dict'):
                params['op_id'] = self.op_id.to_alipay_dict()
            else:
                params['op_id'] = self.op_id
        if self.op_role:
            if hasattr(self.op_role, 'to_alipay_dict'):
                params['op_role'] = self.op_role.to_alipay_dict()
            else:
                params['op_role'] = self.op_role
        if self.operate_notify_url:
            if hasattr(self.operate_notify_url, 'to_alipay_dict'):
                params['operate_notify_url'] = self.operate_notify_url.to_alipay_dict()
            else:
                params['operate_notify_url'] = self.operate_notify_url
        if self.other_authorization:
            if hasattr(self.other_authorization, 'to_alipay_dict'):
                params['other_authorization'] = self.other_authorization.to_alipay_dict()
            else:
                params['other_authorization'] = self.other_authorization
        if self.parking:
            if hasattr(self.parking, 'to_alipay_dict'):
                params['parking'] = self.parking.to_alipay_dict()
            else:
                params['parking'] = self.parking
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.pay_type:
            if hasattr(self.pay_type, 'to_alipay_dict'):
                params['pay_type'] = self.pay_type.to_alipay_dict()
            else:
                params['pay_type'] = self.pay_type
        if self.province_code:
            if hasattr(self.province_code, 'to_alipay_dict'):
                params['province_code'] = self.province_code.to_alipay_dict()
            else:
                params['province_code'] = self.province_code
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        if self.value_added:
            if hasattr(self.value_added, 'to_alipay_dict'):
                params['value_added'] = self.value_added.to_alipay_dict()
            else:
                params['value_added'] = self.value_added
        if self.version:
            if hasattr(self.version, 'to_alipay_dict'):
                params['version'] = self.version.to_alipay_dict()
            else:
                params['version'] = self.version
        if self.wifi:
            if hasattr(self.wifi, 'to_alipay_dict'):
                params['wifi'] = self.wifi.to_alipay_dict()
            else:
                params['wifi'] = self.wifi
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOfflineMarketShopModifyModel()
        if 'address' in d:
            o.address = d['address']
        if 'audit_images' in d:
            o.audit_images = d['audit_images']
        if 'auth_letter' in d:
            o.auth_letter = d['auth_letter']
        if 'avg_price' in d:
            o.avg_price = d['avg_price']
        if 'biz_version' in d:
            o.biz_version = d['biz_version']
        if 'box' in d:
            o.box = d['box']
        if 'branch_shop_name' in d:
            o.branch_shop_name = d['branch_shop_name']
        if 'brand_logo' in d:
            o.brand_logo = d['brand_logo']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'business_certificate' in d:
            o.business_certificate = d['business_certificate']
        if 'business_certificate_expires' in d:
            o.business_certificate_expires = d['business_certificate_expires']
        if 'business_time' in d:
            o.business_time = d['business_time']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'contact_number' in d:
            o.contact_number = d['contact_number']
        if 'district_code' in d:
            o.district_code = d['district_code']
        if 'implement_id' in d:
            o.implement_id = d['implement_id']
        if 'is_operating_online' in d:
            o.is_operating_online = d['is_operating_online']
        if 'is_show' in d:
            o.is_show = d['is_show']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'licence' in d:
            o.licence = d['licence']
        if 'licence_code' in d:
            o.licence_code = d['licence_code']
        if 'licence_expires' in d:
            o.licence_expires = d['licence_expires']
        if 'licence_name' in d:
            o.licence_name = d['licence_name']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'main_image' in d:
            o.main_image = d['main_image']
        if 'main_shop_name' in d:
            o.main_shop_name = d['main_shop_name']
        if 'no_smoking' in d:
            o.no_smoking = d['no_smoking']
        if 'notify_mobile' in d:
            o.notify_mobile = d['notify_mobile']
        if 'online_image' in d:
            o.online_image = d['online_image']
        if 'online_url' in d:
            o.online_url = d['online_url']
        if 'op_id' in d:
            o.op_id = d['op_id']
        if 'op_role' in d:
            o.op_role = d['op_role']
        if 'operate_notify_url' in d:
            o.operate_notify_url = d['operate_notify_url']
        if 'other_authorization' in d:
            o.other_authorization = d['other_authorization']
        if 'parking' in d:
            o.parking = d['parking']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'pay_type' in d:
            o.pay_type = d['pay_type']
        if 'province_code' in d:
            o.province_code = d['province_code']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'store_id' in d:
            o.store_id = d['store_id']
        if 'value_added' in d:
            o.value_added = d['value_added']
        if 'version' in d:
            o.version = d['version']
        if 'wifi' in d:
            o.wifi = d['wifi']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchProductRegion(object):

    def __init__(self):
        self._is_excluded = None
        self._latitude = None
        self._longitude = None
        self._radius = None
        self._region_code = None
        self._region_name = None
        self._region_type = None

    @property
    def is_excluded(self):
        return self._is_excluded

    @is_excluded.setter
    def is_excluded(self, value):
        self._is_excluded = value
    @property
    def latitude(self):
        return self._latitude

    @latitude.setter
    def latitude(self, value):
        self._latitude = value
    @property
    def longitude(self):
        return self._longitude

    @longitude.setter
    def longitude(self, value):
        self._longitude = value
    @property
    def radius(self):
        return self._radius

    @radius.setter
    def radius(self, value):
        self._radius = value
    @property
    def region_code(self):
        return self._region_code

    @region_code.setter
    def region_code(self, value):
        self._region_code = value
    @property
    def region_name(self):
        return self._region_name

    @region_name.setter
    def region_name(self, value):
        self._region_name = value
    @property
    def region_type(self):
        return self._region_type

    @region_type.setter
    def region_type(self, value):
        self._region_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.is_excluded:
            if hasattr(self.is_excluded, 'to_alipay_dict'):
                params['is_excluded'] = self.is_excluded.to_alipay_dict()
            else:
                params['is_excluded'] = self.is_excluded
        if self.latitude:
            if hasattr(self.latitude, 'to_alipay_dict'):
                params['latitude'] = self.latitude.to_alipay_dict()
            else:
                params['latitude'] = self.latitude
        if self.longitude:
            if hasattr(self.longitude, 'to_alipay_dict'):
                params['longitude'] = self.longitude.to_alipay_dict()
            else:
                params['longitude'] = self.longitude
        if self.radius:
            if hasattr(self.radius, 'to_alipay_dict'):
                params['radius'] = self.radius.to_alipay_dict()
            else:
                params['radius'] = self.radius
        if self.region_code:
            if hasattr(self.region_code, 'to_alipay_dict'):
                params['region_code'] = self.region_code.to_alipay_dict()
            else:
                params['region_code'] = self.region_code
        if self.region_name:
            if hasattr(self.region_name, 'to_alipay_dict'):
                params['region_name'] = self.region_name.to_alipay_dict()
            else:
                params['region_name'] = self.region_name
        if self.region_type:
            if hasattr(self.region_type, 'to_alipay_dict'):
                params['region_type'] = self.region_type.to_alipay_dict()
            else:
                params['region_type'] = self.region_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchProductRegion()
        if 'is_excluded' in d:
            o.is_excluded = d['is_excluded']
        if 'latitude' in d:
            o.latitude = d['latitude']
        if 'longitude' in d:
            o.longitude = d['longitude']
        if 'radius' in d:
            o.radius = d['radius']
        if 'region_code' in d:
            o.region_code = d['region_code']
        if 'region_name' in d:
            o.region_name = d['region_name']
        if 'region_type' in d:
            o.region_type = d['region_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipaySecurityProdInteractiveprodInitializeResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySecurityProdInteractiveprodInitializeResponse, self).__init__()
        self._ext_params = None
        self._interact_id = None
        self._interact_url = None

    @property
    def ext_params(self):
        return self._ext_params

    @ext_params.setter
    def ext_params(self, value):
        self._ext_params = value
    @property
    def interact_id(self):
        return self._interact_id

    @interact_id.setter
    def interact_id(self, value):
        self._interact_id = value
    @property
    def interact_url(self):
        return self._interact_url

    @interact_url.setter
    def interact_url(self, value):
        self._interact_url = value

    def parse_response_content(self, response_content):
        response = super(AlipaySecurityProdInteractiveprodInitializeResponse, self).parse_response_content(response_content)
        if 'ext_params' in response:
            self.ext_params = response['ext_params']
        if 'interact_id' in response:
            self.interact_id = response['interact_id']
        if 'interact_url' in response:
            self.interact_url = response['interact_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FailFaceUserInfo(object):

    def __init__(self):
        self._fail_code = None
        self._fail_message = None
        self._retry = None
        self._unique_id = None

    @property
    def fail_code(self):
        return self._fail_code

    @fail_code.setter
    def fail_code(self, value):
        self._fail_code = value
    @property
    def fail_message(self):
        return self._fail_message

    @fail_message.setter
    def fail_message(self, value):
        self._fail_message = value
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def unique_id(self):
        return self._unique_id

    @unique_id.setter
    def unique_id(self, value):
        self._unique_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.fail_code:
            if hasattr(self.fail_code, 'to_alipay_dict'):
                params['fail_code'] = self.fail_code.to_alipay_dict()
            else:
                params['fail_code'] = self.fail_code
        if self.fail_message:
            if hasattr(self.fail_message, 'to_alipay_dict'):
                params['fail_message'] = self.fail_message.to_alipay_dict()
            else:
                params['fail_message'] = self.fail_message
        if self.retry:
            if hasattr(self.retry, 'to_alipay_dict'):
                params['retry'] = self.retry.to_alipay_dict()
            else:
                params['retry'] = self.retry
        if self.unique_id:
            if hasattr(self.unique_id, 'to_alipay_dict'):
                params['unique_id'] = self.unique_id.to_alipay_dict()
            else:
                params['unique_id'] = self.unique_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FailFaceUserInfo()
        if 'fail_code' in d:
            o.fail_code = d['fail_code']
        if 'fail_message' in d:
            o.fail_message = d['fail_message']
        if 'retry' in d:
            o.retry = d['retry']
        if 'unique_id' in d:
            o.unique_id = d['unique_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FsServiceDynamicInfo(object):

    def __init__(self):
        self._content_key = None
        self._content_type = None
        self._content_value = None
        self._end_valid_date = None
        self._start_valid_date = None

    @property
    def content_key(self):
        return self._content_key

    @content_key.setter
    def content_key(self, value):
        self._content_key = value
    @property
    def content_type(self):
        return self._content_type

    @content_type.setter
    def content_type(self, value):
        self._content_type = value
    @property
    def content_value(self):
        return self._content_value

    @content_value.setter
    def content_value(self, value):
        self._content_value = value
    @property
    def end_valid_date(self):
        return self._end_valid_date

    @end_valid_date.setter
    def end_valid_date(self, value):
        self._end_valid_date = value
    @property
    def start_valid_date(self):
        return self._start_valid_date

    @start_valid_date.setter
    def start_valid_date(self, value):
        self._start_valid_date = value


    def to_alipay_dict(self):
        params = dict()
        if self.content_key:
            if hasattr(self.content_key, 'to_alipay_dict'):
                params['content_key'] = self.content_key.to_alipay_dict()
            else:
                params['content_key'] = self.content_key
        if self.content_type:
            if hasattr(self.content_type, 'to_alipay_dict'):
                params['content_type'] = self.content_type.to_alipay_dict()
            else:
                params['content_type'] = self.content_type
        if self.content_value:
            if hasattr(self.content_value, 'to_alipay_dict'):
                params['content_value'] = self.content_value.to_alipay_dict()
            else:
                params['content_value'] = self.content_value
        if self.end_valid_date:
            if hasattr(self.end_valid_date, 'to_alipay_dict'):
                params['end_valid_date'] = self.end_valid_date.to_alipay_dict()
            else:
                params['end_valid_date'] = self.end_valid_date
        if self.start_valid_date:
            if hasattr(self.start_valid_date, 'to_alipay_dict'):
                params['start_valid_date'] = self.start_valid_date.to_alipay_dict()
            else:
                params['start_valid_date'] = self.start_valid_date
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FsServiceDynamicInfo()
        if 'content_key' in d:
            o.content_key = d['content_key']
        if 'content_type' in d:
            o.content_type = d['content_type']
        if 'content_value' in d:
            o.content_value = d['content_value']
        if 'end_valid_date' in d:
            o.end_valid_date = d['end_valid_date']
        if 'start_valid_date' in d:
            o.start_valid_date = d['start_valid_date']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbPosOrderDishDetail import KbPosOrderDishDetail
from alipay.aop.api.domain.PosOrderKey import PosOrderKey


class KoubeiCateringOrderInfoModifyModel(object):

    def __init__(self):
        self._action = None
        self._dish_details = None
        self._ext_info = None
        self._memo = None
        self._other_amount = None
        self._packing_amount = None
        self._people_num = None
        self._pos_order_key = None
        self._service_amount = None
        self._take_no = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def dish_details(self):
        return self._dish_details

    @dish_details.setter
    def dish_details(self, value):
        if isinstance(value, list):
            self._dish_details = list()
            for i in value:
                if isinstance(i, KbPosOrderDishDetail):
                    self._dish_details.append(i)
                else:
                    self._dish_details.append(KbPosOrderDishDetail.from_alipay_dict(i))
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def other_amount(self):
        return self._other_amount

    @other_amount.setter
    def other_amount(self, value):
        self._other_amount = value
    @property
    def packing_amount(self):
        return self._packing_amount

    @packing_amount.setter
    def packing_amount(self, value):
        self._packing_amount = value
    @property
    def people_num(self):
        return self._people_num

    @people_num.setter
    def people_num(self, value):
        self._people_num = value
    @property
    def pos_order_key(self):
        return self._pos_order_key

    @pos_order_key.setter
    def pos_order_key(self, value):
        if isinstance(value, PosOrderKey):
            self._pos_order_key = value
        else:
            self._pos_order_key = PosOrderKey.from_alipay_dict(value)
    @property
    def service_amount(self):
        return self._service_amount

    @service_amount.setter
    def service_amount(self, value):
        self._service_amount = value
    @property
    def take_no(self):
        return self._take_no

    @take_no.setter
    def take_no(self, value):
        self._take_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.dish_details:
            if isinstance(self.dish_details, list):
                for i in range(0, len(self.dish_details)):
                    element = self.dish_details[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.dish_details[i] = element.to_alipay_dict()
            if hasattr(self.dish_details, 'to_alipay_dict'):
                params['dish_details'] = self.dish_details.to_alipay_dict()
            else:
                params['dish_details'] = self.dish_details
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.other_amount:
            if hasattr(self.other_amount, 'to_alipay_dict'):
                params['other_amount'] = self.other_amount.to_alipay_dict()
            else:
                params['other_amount'] = self.other_amount
        if self.packing_amount:
            if hasattr(self.packing_amount, 'to_alipay_dict'):
                params['packing_amount'] = self.packing_amount.to_alipay_dict()
            else:
                params['packing_amount'] = self.packing_amount
        if self.people_num:
            if hasattr(self.people_num, 'to_alipay_dict'):
                params['people_num'] = self.people_num.to_alipay_dict()
            else:
                params['people_num'] = self.people_num
        if self.pos_order_key:
            if hasattr(self.pos_order_key, 'to_alipay_dict'):
                params['pos_order_key'] = self.pos_order_key.to_alipay_dict()
            else:
                params['pos_order_key'] = self.pos_order_key
        if self.service_amount:
            if hasattr(self.service_amount, 'to_alipay_dict'):
                params['service_amount'] = self.service_amount.to_alipay_dict()
            else:
                params['service_amount'] = self.service_amount
        if self.take_no:
            if hasattr(self.take_no, 'to_alipay_dict'):
                params['take_no'] = self.take_no.to_alipay_dict()
            else:
                params['take_no'] = self.take_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringOrderInfoModifyModel()
        if 'action' in d:
            o.action = d['action']
        if 'dish_details' in d:
            o.dish_details = d['dish_details']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'memo' in d:
            o.memo = d['memo']
        if 'other_amount' in d:
            o.other_amount = d['other_amount']
        if 'packing_amount' in d:
            o.packing_amount = d['packing_amount']
        if 'people_num' in d:
            o.people_num = d['people_num']
        if 'pos_order_key' in d:
            o.pos_order_key = d['pos_order_key']
        if 'service_amount' in d:
            o.service_amount = d['service_amount']
        if 'take_no' in d:
            o.take_no = d['take_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.FdsPayFundItemDTO import FdsPayFundItemDTO


class AlipayFincoreFunddsOrderWitnessQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFincoreFunddsOrderWitnessQueryResponse, self).__init__()
        self._fds_no = None
        self._gmt_create = None
        self._out_request_no = None
        self._pay_fund_item_list = None
        self._total_amount = None

    @property
    def fds_no(self):
        return self._fds_no

    @fds_no.setter
    def fds_no(self, value):
        self._fds_no = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def pay_fund_item_list(self):
        return self._pay_fund_item_list

    @pay_fund_item_list.setter
    def pay_fund_item_list(self, value):
        if isinstance(value, list):
            self._pay_fund_item_list = list()
            for i in value:
                if isinstance(i, FdsPayFundItemDTO):
                    self._pay_fund_item_list.append(i)
                else:
                    self._pay_fund_item_list.append(FdsPayFundItemDTO.from_alipay_dict(i))
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value

    def parse_response_content(self, response_content):
        response = super(AlipayFincoreFunddsOrderWitnessQueryResponse, self).parse_response_content(response_content)
        if 'fds_no' in response:
            self.fds_no = response['fds_no']
        if 'gmt_create' in response:
            self.gmt_create = response['gmt_create']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'pay_fund_item_list' in response:
            self.pay_fund_item_list = response['pay_fund_item_list']
        if 'total_amount' in response:
            self.total_amount = response['total_amount']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TextInstance(object):

    def __init__(self):
        self._key = None
        self._material_type = None
        self._value = None

    @property
    def key(self):
        return self._key

    @key.setter
    def key(self, value):
        self._key = value
    @property
    def material_type(self):
        return self._material_type

    @material_type.setter
    def material_type(self, value):
        self._material_type = value
    @property
    def value(self):
        return self._value

    @value.setter
    def value(self, value):
        self._value = value


    def to_alipay_dict(self):
        params = dict()
        if self.key:
            if hasattr(self.key, 'to_alipay_dict'):
                params['key'] = self.key.to_alipay_dict()
            else:
                params['key'] = self.key
        if self.material_type:
            if hasattr(self.material_type, 'to_alipay_dict'):
                params['material_type'] = self.material_type.to_alipay_dict()
            else:
                params['material_type'] = self.material_type
        if self.value:
            if hasattr(self.value, 'to_alipay_dict'):
                params['value'] = self.value.to_alipay_dict()
            else:
                params['value'] = self.value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TextInstance()
        if 'key' in d:
            o.key = d['key']
        if 'material_type' in d:
            o.material_type = d['material_type']
        if 'value' in d:
            o.value = d['value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MExtInfo import MExtInfo
from alipay.aop.api.domain.MPromoInfo import MPromoInfo


class MActivityDetailInfo(object):

    def __init__(self):
        self._activity_id = None
        self._activity_status = None
        self._auto_delay_flag = None
        self._biz_scene = None
        self._creator = None
        self._creator_type = None
        self._desc = None
        self._display_status = None
        self._end_time = None
        self._ext_info = None
        self._name = None
        self._out_biz_type = None
        self._owner_id = None
        self._owner_type = None
        self._promo_info_list = None
        self._start_time = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def activity_status(self):
        return self._activity_status

    @activity_status.setter
    def activity_status(self, value):
        self._activity_status = value
    @property
    def auto_delay_flag(self):
        return self._auto_delay_flag

    @auto_delay_flag.setter
    def auto_delay_flag(self, value):
        self._auto_delay_flag = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def creator(self):
        return self._creator

    @creator.setter
    def creator(self, value):
        self._creator = value
    @property
    def creator_type(self):
        return self._creator_type

    @creator_type.setter
    def creator_type(self, value):
        self._creator_type = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def display_status(self):
        return self._display_status

    @display_status.setter
    def display_status(self, value):
        self._display_status = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, MExtInfo):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(MExtInfo.from_alipay_dict(i))
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def out_biz_type(self):
        return self._out_biz_type

    @out_biz_type.setter
    def out_biz_type(self, value):
        self._out_biz_type = value
    @property
    def owner_id(self):
        return self._owner_id

    @owner_id.setter
    def owner_id(self, value):
        self._owner_id = value
    @property
    def owner_type(self):
        return self._owner_type

    @owner_type.setter
    def owner_type(self, value):
        self._owner_type = value
    @property
    def promo_info_list(self):
        return self._promo_info_list

    @promo_info_list.setter
    def promo_info_list(self, value):
        if isinstance(value, list):
            self._promo_info_list = list()
            for i in value:
                if isinstance(i, MPromoInfo):
                    self._promo_info_list.append(i)
                else:
                    self._promo_info_list.append(MPromoInfo.from_alipay_dict(i))
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.activity_status:
            if hasattr(self.activity_status, 'to_alipay_dict'):
                params['activity_status'] = self.activity_status.to_alipay_dict()
            else:
                params['activity_status'] = self.activity_status
        if self.auto_delay_flag:
            if hasattr(self.auto_delay_flag, 'to_alipay_dict'):
                params['auto_delay_flag'] = self.auto_delay_flag.to_alipay_dict()
            else:
                params['auto_delay_flag'] = self.auto_delay_flag
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.creator:
            if hasattr(self.creator, 'to_alipay_dict'):
                params['creator'] = self.creator.to_alipay_dict()
            else:
                params['creator'] = self.creator
        if self.creator_type:
            if hasattr(self.creator_type, 'to_alipay_dict'):
                params['creator_type'] = self.creator_type.to_alipay_dict()
            else:
                params['creator_type'] = self.creator_type
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.display_status:
            if hasattr(self.display_status, 'to_alipay_dict'):
                params['display_status'] = self.display_status.to_alipay_dict()
            else:
                params['display_status'] = self.display_status
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.out_biz_type:
            if hasattr(self.out_biz_type, 'to_alipay_dict'):
                params['out_biz_type'] = self.out_biz_type.to_alipay_dict()
            else:
                params['out_biz_type'] = self.out_biz_type
        if self.owner_id:
            if hasattr(self.owner_id, 'to_alipay_dict'):
                params['owner_id'] = self.owner_id.to_alipay_dict()
            else:
                params['owner_id'] = self.owner_id
        if self.owner_type:
            if hasattr(self.owner_type, 'to_alipay_dict'):
                params['owner_type'] = self.owner_type.to_alipay_dict()
            else:
                params['owner_type'] = self.owner_type
        if self.promo_info_list:
            if isinstance(self.promo_info_list, list):
                for i in range(0, len(self.promo_info_list)):
                    element = self.promo_info_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.promo_info_list[i] = element.to_alipay_dict()
            if hasattr(self.promo_info_list, 'to_alipay_dict'):
                params['promo_info_list'] = self.promo_info_list.to_alipay_dict()
            else:
                params['promo_info_list'] = self.promo_info_list
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MActivityDetailInfo()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'activity_status' in d:
            o.activity_status = d['activity_status']
        if 'auto_delay_flag' in d:
            o.auto_delay_flag = d['auto_delay_flag']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'creator' in d:
            o.creator = d['creator']
        if 'creator_type' in d:
            o.creator_type = d['creator_type']
        if 'desc' in d:
            o.desc = d['desc']
        if 'display_status' in d:
            o.display_status = d['display_status']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'name' in d:
            o.name = d['name']
        if 'out_biz_type' in d:
            o.out_biz_type = d['out_biz_type']
        if 'owner_id' in d:
            o.owner_id = d['owner_id']
        if 'owner_type' in d:
            o.owner_type = d['owner_type']
        if 'promo_info_list' in d:
            o.promo_info_list = d['promo_info_list']
        if 'start_time' in d:
            o.start_time = d['start_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenApiPassStatus import OpenApiPassStatus
from alipay.aop.api.domain.OpenApiResponseHeader import OpenApiResponseHeader


class AlipayUserApplepayPbstatusQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserApplepayPbstatusQueryResponse, self).__init__()
        self._pass_status_list = None
        self._response_header = None
        self._state = None

    @property
    def pass_status_list(self):
        return self._pass_status_list

    @pass_status_list.setter
    def pass_status_list(self, value):
        if isinstance(value, OpenApiPassStatus):
            self._pass_status_list = value
        else:
            self._pass_status_list = OpenApiPassStatus.from_alipay_dict(value)
    @property
    def response_header(self):
        return self._response_header

    @response_header.setter
    def response_header(self, value):
        if isinstance(value, OpenApiResponseHeader):
            self._response_header = value
        else:
            self._response_header = OpenApiResponseHeader.from_alipay_dict(value)
    @property
    def state(self):
        return self._state

    @state.setter
    def state(self, value):
        self._state = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserApplepayPbstatusQueryResponse, self).parse_response_content(response_content)
        if 'pass_status_list' in response:
            self.pass_status_list = response['pass_status_list']
        if 'response_header' in response:
            self.response_header = response['response_header']
        if 'state' in response:
            self.state = response['state']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserUnicomCardInfoSyncResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserUnicomCardInfoSyncResponse, self).__init__()
        self._card_sync_result = None
        self._phone_no = None
        self._user_id = None

    @property
    def card_sync_result(self):
        return self._card_sync_result

    @card_sync_result.setter
    def card_sync_result(self, value):
        self._card_sync_result = value
    @property
    def phone_no(self):
        return self._phone_no

    @phone_no.setter
    def phone_no(self, value):
        self._phone_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserUnicomCardInfoSyncResponse, self).parse_response_content(response_content)
        if 'card_sync_result' in response:
            self.card_sync_result = response['card_sync_result']
        if 'phone_no' in response:
            self.phone_no = response['phone_no']
        if 'user_id' in response:
            self.user_id = response['user_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InsOrderInfo(object):

    def __init__(self):
        self._biz_data = None
        self._order_accept_time = None
        self._order_actual_fee = None
        self._order_expected_time = None
        self._order_finish_time = None
        self._order_no = None
        self._order_status = None
        self._order_time = None

    @property
    def biz_data(self):
        return self._biz_data

    @biz_data.setter
    def biz_data(self, value):
        self._biz_data = value
    @property
    def order_accept_time(self):
        return self._order_accept_time

    @order_accept_time.setter
    def order_accept_time(self, value):
        self._order_accept_time = value
    @property
    def order_actual_fee(self):
        return self._order_actual_fee

    @order_actual_fee.setter
    def order_actual_fee(self, value):
        self._order_actual_fee = value
    @property
    def order_expected_time(self):
        return self._order_expected_time

    @order_expected_time.setter
    def order_expected_time(self, value):
        self._order_expected_time = value
    @property
    def order_finish_time(self):
        return self._order_finish_time

    @order_finish_time.setter
    def order_finish_time(self, value):
        self._order_finish_time = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_status(self):
        return self._order_status

    @order_status.setter
    def order_status(self, value):
        self._order_status = value
    @property
    def order_time(self):
        return self._order_time

    @order_time.setter
    def order_time(self, value):
        self._order_time = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_data:
            if hasattr(self.biz_data, 'to_alipay_dict'):
                params['biz_data'] = self.biz_data.to_alipay_dict()
            else:
                params['biz_data'] = self.biz_data
        if self.order_accept_time:
            if hasattr(self.order_accept_time, 'to_alipay_dict'):
                params['order_accept_time'] = self.order_accept_time.to_alipay_dict()
            else:
                params['order_accept_time'] = self.order_accept_time
        if self.order_actual_fee:
            if hasattr(self.order_actual_fee, 'to_alipay_dict'):
                params['order_actual_fee'] = self.order_actual_fee.to_alipay_dict()
            else:
                params['order_actual_fee'] = self.order_actual_fee
        if self.order_expected_time:
            if hasattr(self.order_expected_time, 'to_alipay_dict'):
                params['order_expected_time'] = self.order_expected_time.to_alipay_dict()
            else:
                params['order_expected_time'] = self.order_expected_time
        if self.order_finish_time:
            if hasattr(self.order_finish_time, 'to_alipay_dict'):
                params['order_finish_time'] = self.order_finish_time.to_alipay_dict()
            else:
                params['order_finish_time'] = self.order_finish_time
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.order_status:
            if hasattr(self.order_status, 'to_alipay_dict'):
                params['order_status'] = self.order_status.to_alipay_dict()
            else:
                params['order_status'] = self.order_status
        if self.order_time:
            if hasattr(self.order_time, 'to_alipay_dict'):
                params['order_time'] = self.order_time.to_alipay_dict()
            else:
                params['order_time'] = self.order_time
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InsOrderInfo()
        if 'biz_data' in d:
            o.biz_data = d['biz_data']
        if 'order_accept_time' in d:
            o.order_accept_time = d['order_accept_time']
        if 'order_actual_fee' in d:
            o.order_actual_fee = d['order_actual_fee']
        if 'order_expected_time' in d:
            o.order_expected_time = d['order_expected_time']
        if 'order_finish_time' in d:
            o.order_finish_time = d['order_finish_time']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'order_status' in d:
            o.order_status = d['order_status']
        if 'order_time' in d:
            o.order_time = d['order_time']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceTransportEtcBlacklistQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportEtcBlacklistQueryResponse, self).__init__()
        self._blacklist_code = None
        self._blacklist_desc = None
        self._blacklist_status = None
        self._in_time = None
        self._out_time = None
        self._plate_color = None
        self._plate_no = None

    @property
    def blacklist_code(self):
        return self._blacklist_code

    @blacklist_code.setter
    def blacklist_code(self, value):
        self._blacklist_code = value
    @property
    def blacklist_desc(self):
        return self._blacklist_desc

    @blacklist_desc.setter
    def blacklist_desc(self, value):
        self._blacklist_desc = value
    @property
    def blacklist_status(self):
        return self._blacklist_status

    @blacklist_status.setter
    def blacklist_status(self, value):
        self._blacklist_status = value
    @property
    def in_time(self):
        return self._in_time

    @in_time.setter
    def in_time(self, value):
        self._in_time = value
    @property
    def out_time(self):
        return self._out_time

    @out_time.setter
    def out_time(self, value):
        self._out_time = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportEtcBlacklistQueryResponse, self).parse_response_content(response_content)
        if 'blacklist_code' in response:
            self.blacklist_code = response['blacklist_code']
        if 'blacklist_desc' in response:
            self.blacklist_desc = response['blacklist_desc']
        if 'blacklist_status' in response:
            self.blacklist_status = response['blacklist_status']
        if 'in_time' in response:
            self.in_time = response['in_time']
        if 'out_time' in response:
            self.out_time = response['out_time']
        if 'plate_color' in response:
            self.plate_color = response['plate_color']
        if 'plate_no' in response:
            self.plate_no = response['plate_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class KoubeiMarketingAdvertisingQueryResponse(AlipayResponse):

    def __init__(self):
        super(KoubeiMarketingAdvertisingQueryResponse, self).__init__()
        self._action_url = None
        self._ad_code = None
        self._ad_rules = None
        self._content = None
        self._content_type = None
        self._end_time = None
        self._height = None
        self._start_time = None
        self._status = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def ad_code(self):
        return self._ad_code

    @ad_code.setter
    def ad_code(self, value):
        self._ad_code = value
    @property
    def ad_rules(self):
        return self._ad_rules

    @ad_rules.setter
    def ad_rules(self, value):
        self._ad_rules = value
    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def content_type(self):
        return self._content_type

    @content_type.setter
    def content_type(self, value):
        self._content_type = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def height(self):
        return self._height

    @height.setter
    def height(self, value):
        self._height = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(KoubeiMarketingAdvertisingQueryResponse, self).parse_response_content(response_content)
        if 'action_url' in response:
            self.action_url = response['action_url']
        if 'ad_code' in response:
            self.ad_code = response['ad_code']
        if 'ad_rules' in response:
            self.ad_rules = response['ad_rules']
        if 'content' in response:
            self.content = response['content']
        if 'content_type' in response:
            self.content_type = response['content_type']
        if 'end_time' in response:
            self.end_time = response['end_time']
        if 'height' in response:
            self.height = response['height']
        if 'start_time' in response:
            self.start_time = response['start_time']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerbaseinfoModifyModel(object):

    def __init__(self):
        self._app_alias_name = None
        self._app_category_ids = None
        self._app_desc = None
        self._app_english_name = None
        self._app_key = None
        self._app_logo = None
        self._app_name = None
        self._app_slogan = None
        self._inst_code = None
        self._mini_app_id = None
        self._service_email = None
        self._service_phone = None

    @property
    def app_alias_name(self):
        return self._app_alias_name

    @app_alias_name.setter
    def app_alias_name(self, value):
        self._app_alias_name = value
    @property
    def app_category_ids(self):
        return self._app_category_ids

    @app_category_ids.setter
    def app_category_ids(self, value):
        self._app_category_ids = value
    @property
    def app_desc(self):
        return self._app_desc

    @app_desc.setter
    def app_desc(self, value):
        self._app_desc = value
    @property
    def app_english_name(self):
        return self._app_english_name

    @app_english_name.setter
    def app_english_name(self, value):
        self._app_english_name = value
    @property
    def app_key(self):
        return self._app_key

    @app_key.setter
    def app_key(self, value):
        self._app_key = value
    @property
    def app_logo(self):
        return self._app_logo

    @app_logo.setter
    def app_logo(self, value):
        self._app_logo = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_slogan(self):
        return self._app_slogan

    @app_slogan.setter
    def app_slogan(self, value):
        self._app_slogan = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def service_email(self):
        return self._service_email

    @service_email.setter
    def service_email(self, value):
        self._service_email = value
    @property
    def service_phone(self):
        return self._service_phone

    @service_phone.setter
    def service_phone(self, value):
        self._service_phone = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_alias_name:
            if hasattr(self.app_alias_name, 'to_alipay_dict'):
                params['app_alias_name'] = self.app_alias_name.to_alipay_dict()
            else:
                params['app_alias_name'] = self.app_alias_name
        if self.app_category_ids:
            if hasattr(self.app_category_ids, 'to_alipay_dict'):
                params['app_category_ids'] = self.app_category_ids.to_alipay_dict()
            else:
                params['app_category_ids'] = self.app_category_ids
        if self.app_desc:
            if hasattr(self.app_desc, 'to_alipay_dict'):
                params['app_desc'] = self.app_desc.to_alipay_dict()
            else:
                params['app_desc'] = self.app_desc
        if self.app_english_name:
            if hasattr(self.app_english_name, 'to_alipay_dict'):
                params['app_english_name'] = self.app_english_name.to_alipay_dict()
            else:
                params['app_english_name'] = self.app_english_name
        if self.app_key:
            if hasattr(self.app_key, 'to_alipay_dict'):
                params['app_key'] = self.app_key.to_alipay_dict()
            else:
                params['app_key'] = self.app_key
        if self.app_logo:
            if hasattr(self.app_logo, 'to_alipay_dict'):
                params['app_logo'] = self.app_logo.to_alipay_dict()
            else:
                params['app_logo'] = self.app_logo
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_slogan:
            if hasattr(self.app_slogan, 'to_alipay_dict'):
                params['app_slogan'] = self.app_slogan.to_alipay_dict()
            else:
                params['app_slogan'] = self.app_slogan
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.service_email:
            if hasattr(self.service_email, 'to_alipay_dict'):
                params['service_email'] = self.service_email.to_alipay_dict()
            else:
                params['service_email'] = self.service_email
        if self.service_phone:
            if hasattr(self.service_phone, 'to_alipay_dict'):
                params['service_phone'] = self.service_phone.to_alipay_dict()
            else:
                params['service_phone'] = self.service_phone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerbaseinfoModifyModel()
        if 'app_alias_name' in d:
            o.app_alias_name = d['app_alias_name']
        if 'app_category_ids' in d:
            o.app_category_ids = d['app_category_ids']
        if 'app_desc' in d:
            o.app_desc = d['app_desc']
        if 'app_english_name' in d:
            o.app_english_name = d['app_english_name']
        if 'app_key' in d:
            o.app_key = d['app_key']
        if 'app_logo' in d:
            o.app_logo = d['app_logo']
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_slogan' in d:
            o.app_slogan = d['app_slogan']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'service_email' in d:
            o.service_email = d['service_email']
        if 'service_phone' in d:
            o.service_phone = d['service_phone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransEdumigrateMigrateserviceModifyModel(object):

    def __init__(self):
        self._handler = None
        self._params = None

    @property
    def handler(self):
        return self._handler

    @handler.setter
    def handler(self, value):
        self._handler = value
    @property
    def params(self):
        return self._params

    @params.setter
    def params(self, value):
        self._params = value


    def to_alipay_dict(self):
        params = dict()
        if self.handler:
            if hasattr(self.handler, 'to_alipay_dict'):
                params['handler'] = self.handler.to_alipay_dict()
            else:
                params['handler'] = self.handler
        if self.params:
            if hasattr(self.params, 'to_alipay_dict'):
                params['params'] = self.params.to_alipay_dict()
            else:
                params['params'] = self.params
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransEdumigrateMigrateserviceModifyModel()
        if 'handler' in d:
            o.handler = d['handler']
        if 'params' in d:
            o.params = d['params']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipaySecurityRiskContentAnalyzeModel(object):

    def __init__(self):
        self._account_id = None
        self._account_type = None
        self._app_main_scene = None
        self._app_main_scene_id = None
        self._app_name = None
        self._app_scene = None
        self._app_scene_data_id = None
        self._audio_urls = None
        self._link_urls = None
        self._picture_urls = None
        self._publish_date = None
        self._text = None
        self._text_type = None
        self._video_urls = None

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, value):
        self._account_id = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def app_main_scene(self):
        return self._app_main_scene

    @app_main_scene.setter
    def app_main_scene(self, value):
        self._app_main_scene = value
    @property
    def app_main_scene_id(self):
        return self._app_main_scene_id

    @app_main_scene_id.setter
    def app_main_scene_id(self, value):
        self._app_main_scene_id = value
    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def app_scene(self):
        return self._app_scene

    @app_scene.setter
    def app_scene(self, value):
        self._app_scene = value
    @property
    def app_scene_data_id(self):
        return self._app_scene_data_id

    @app_scene_data_id.setter
    def app_scene_data_id(self, value):
        self._app_scene_data_id = value
    @property
    def audio_urls(self):
        return self._audio_urls

    @audio_urls.setter
    def audio_urls(self, value):
        if isinstance(value, list):
            self._audio_urls = list()
            for i in value:
                self._audio_urls.append(i)
    @property
    def link_urls(self):
        return self._link_urls

    @link_urls.setter
    def link_urls(self, value):
        if isinstance(value, list):
            self._link_urls = list()
            for i in value:
                self._link_urls.append(i)
    @property
    def picture_urls(self):
        return self._picture_urls

    @picture_urls.setter
    def picture_urls(self, value):
        if isinstance(value, list):
            self._picture_urls = list()
            for i in value:
                self._picture_urls.append(i)
    @property
    def publish_date(self):
        return self._publish_date

    @publish_date.setter
    def publish_date(self, value):
        self._publish_date = value
    @property
    def text(self):
        return self._text

    @text.setter
    def text(self, value):
        self._text = value
    @property
    def text_type(self):
        return self._text_type

    @text_type.setter
    def text_type(self, value):
        self._text_type = value
    @property
    def video_urls(self):
        return self._video_urls

    @video_urls.setter
    def video_urls(self, value):
        if isinstance(value, list):
            self._video_urls = list()
            for i in value:
                self._video_urls.append(i)


    def to_alipay_dict(self):
        params = dict()
        if self.account_id:
            if hasattr(self.account_id, 'to_alipay_dict'):
                params['account_id'] = self.account_id.to_alipay_dict()
            else:
                params['account_id'] = self.account_id
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.app_main_scene:
            if hasattr(self.app_main_scene, 'to_alipay_dict'):
                params['app_main_scene'] = self.app_main_scene.to_alipay_dict()
            else:
                params['app_main_scene'] = self.app_main_scene
        if self.app_main_scene_id:
            if hasattr(self.app_main_scene_id, 'to_alipay_dict'):
                params['app_main_scene_id'] = self.app_main_scene_id.to_alipay_dict()
            else:
                params['app_main_scene_id'] = self.app_main_scene_id
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.app_scene:
            if hasattr(self.app_scene, 'to_alipay_dict'):
                params['app_scene'] = self.app_scene.to_alipay_dict()
            else:
                params['app_scene'] = self.app_scene
        if self.app_scene_data_id:
            if hasattr(self.app_scene_data_id, 'to_alipay_dict'):
                params['app_scene_data_id'] = self.app_scene_data_id.to_alipay_dict()
            else:
                params['app_scene_data_id'] = self.app_scene_data_id
        if self.audio_urls:
            if isinstance(self.audio_urls, list):
                for i in range(0, len(self.audio_urls)):
                    element = self.audio_urls[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.audio_urls[i] = element.to_alipay_dict()
            if hasattr(self.audio_urls, 'to_alipay_dict'):
                params['audio_urls'] = self.audio_urls.to_alipay_dict()
            else:
                params['audio_urls'] = self.audio_urls
        if self.link_urls:
            if isinstance(self.link_urls, list):
                for i in range(0, len(self.link_urls)):
                    element = self.link_urls[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.link_urls[i] = element.to_alipay_dict()
            if hasattr(self.link_urls, 'to_alipay_dict'):
                params['link_urls'] = self.link_urls.to_alipay_dict()
            else:
                params['link_urls'] = self.link_urls
        if self.picture_urls:
            if isinstance(self.picture_urls, list):
                for i in range(0, len(self.picture_urls)):
                    element = self.picture_urls[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.picture_urls[i] = element.to_alipay_dict()
            if hasattr(self.picture_urls, 'to_alipay_dict'):
                params['picture_urls'] = self.picture_urls.to_alipay_dict()
            else:
                params['picture_urls'] = self.picture_urls
        if self.publish_date:
            if hasattr(self.publish_date, 'to_alipay_dict'):
                params['publish_date'] = self.publish_date.to_alipay_dict()
            else:
                params['publish_date'] = self.publish_date
        if self.text:
            if hasattr(self.text, 'to_alipay_dict'):
                params['text'] = self.text.to_alipay_dict()
            else:
                params['text'] = self.text
        if self.text_type:
            if hasattr(self.text_type, 'to_alipay_dict'):
                params['text_type'] = self.text_type.to_alipay_dict()
            else:
                params['text_type'] = self.text_type
        if self.video_urls:
            if isinstance(self.video_urls, list):
                for i in range(0, len(self.video_urls)):
                    element = self.video_urls[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.video_urls[i] = element.to_alipay_dict()
            if hasattr(self.video_urls, 'to_alipay_dict'):
                params['video_urls'] = self.video_urls.to_alipay_dict()
            else:
                params['video_urls'] = self.video_urls
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityRiskContentAnalyzeModel()
        if 'account_id' in d:
            o.account_id = d['account_id']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'app_main_scene' in d:
            o.app_main_scene = d['app_main_scene']
        if 'app_main_scene_id' in d:
            o.app_main_scene_id = d['app_main_scene_id']
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'app_scene' in d:
            o.app_scene = d['app_scene']
        if 'app_scene_data_id' in d:
            o.app_scene_data_id = d['app_scene_data_id']
        if 'audio_urls' in d:
            o.audio_urls = d['audio_urls']
        if 'link_urls' in d:
            o.link_urls = d['link_urls']
        if 'picture_urls' in d:
            o.picture_urls = d['picture_urls']
        if 'publish_date' in d:
            o.publish_date = d['publish_date']
        if 'text' in d:
            o.text = d['text']
        if 'text_type' in d:
            o.text_type = d['text_type']
        if 'video_urls' in d:
            o.video_urls = d['video_urls']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppInstserviceTokenCreateModel(object):

    def __init__(self):
        self._agent_channel = None
        self._agent_code = None
        self._bill_key = None
        self._biz_scene = None
        self._biz_type = None
        self._deduct_amount = None
        self._ededuct_product_code = None
        self._execute_date = None
        self._inst_id = None
        self._out_agreement_id = None
        self._pay_mode = None
        self._service_desc = None
        self._sub_biz_type = None
        self._threshold_amount = None
        self._title = None

    @property
    def agent_channel(self):
        return self._agent_channel

    @agent_channel.setter
    def agent_channel(self, value):
        self._agent_channel = value
    @property
    def agent_code(self):
        return self._agent_code

    @agent_code.setter
    def agent_code(self, value):
        self._agent_code = value
    @property
    def bill_key(self):
        return self._bill_key

    @bill_key.setter
    def bill_key(self, value):
        self._bill_key = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def deduct_amount(self):
        return self._deduct_amount

    @deduct_amount.setter
    def deduct_amount(self, value):
        self._deduct_amount = value
    @property
    def ededuct_product_code(self):
        return self._ededuct_product_code

    @ededuct_product_code.setter
    def ededuct_product_code(self, value):
        self._ededuct_product_code = value
    @property
    def execute_date(self):
        return self._execute_date

    @execute_date.setter
    def execute_date(self, value):
        self._execute_date = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def out_agreement_id(self):
        return self._out_agreement_id

    @out_agreement_id.setter
    def out_agreement_id(self, value):
        self._out_agreement_id = value
    @property
    def pay_mode(self):
        return self._pay_mode

    @pay_mode.setter
    def pay_mode(self, value):
        self._pay_mode = value
    @property
    def service_desc(self):
        return self._service_desc

    @service_desc.setter
    def service_desc(self, value):
        self._service_desc = value
    @property
    def sub_biz_type(self):
        return self._sub_biz_type

    @sub_biz_type.setter
    def sub_biz_type(self, value):
        self._sub_biz_type = value
    @property
    def threshold_amount(self):
        return self._threshold_amount

    @threshold_amount.setter
    def threshold_amount(self, value):
        self._threshold_amount = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.agent_channel:
            if hasattr(self.agent_channel, 'to_alipay_dict'):
                params['agent_channel'] = self.agent_channel.to_alipay_dict()
            else:
                params['agent_channel'] = self.agent_channel
        if self.agent_code:
            if hasattr(self.agent_code, 'to_alipay_dict'):
                params['agent_code'] = self.agent_code.to_alipay_dict()
            else:
                params['agent_code'] = self.agent_code
        if self.bill_key:
            if hasattr(self.bill_key, 'to_alipay_dict'):
                params['bill_key'] = self.bill_key.to_alipay_dict()
            else:
                params['bill_key'] = self.bill_key
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.deduct_amount:
            if hasattr(self.deduct_amount, 'to_alipay_dict'):
                params['deduct_amount'] = self.deduct_amount.to_alipay_dict()
            else:
                params['deduct_amount'] = self.deduct_amount
        if self.ededuct_product_code:
            if hasattr(self.ededuct_product_code, 'to_alipay_dict'):
                params['ededuct_product_code'] = self.ededuct_product_code.to_alipay_dict()
            else:
                params['ededuct_product_code'] = self.ededuct_product_code
        if self.execute_date:
            if hasattr(self.execute_date, 'to_alipay_dict'):
                params['execute_date'] = self.execute_date.to_alipay_dict()
            else:
                params['execute_date'] = self.execute_date
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.out_agreement_id:
            if hasattr(self.out_agreement_id, 'to_alipay_dict'):
                params['out_agreement_id'] = self.out_agreement_id.to_alipay_dict()
            else:
                params['out_agreement_id'] = self.out_agreement_id
        if self.pay_mode:
            if hasattr(self.pay_mode, 'to_alipay_dict'):
                params['pay_mode'] = self.pay_mode.to_alipay_dict()
            else:
                params['pay_mode'] = self.pay_mode
        if self.service_desc:
            if hasattr(self.service_desc, 'to_alipay_dict'):
                params['service_desc'] = self.service_desc.to_alipay_dict()
            else:
                params['service_desc'] = self.service_desc
        if self.sub_biz_type:
            if hasattr(self.sub_biz_type, 'to_alipay_dict'):
                params['sub_biz_type'] = self.sub_biz_type.to_alipay_dict()
            else:
                params['sub_biz_type'] = self.sub_biz_type
        if self.threshold_amount:
            if hasattr(self.threshold_amount, 'to_alipay_dict'):
                params['threshold_amount'] = self.threshold_amount.to_alipay_dict()
            else:
                params['threshold_amount'] = self.threshold_amount
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppInstserviceTokenCreateModel()
        if 'agent_channel' in d:
            o.agent_channel = d['agent_channel']
        if 'agent_code' in d:
            o.agent_code = d['agent_code']
        if 'bill_key' in d:
            o.bill_key = d['bill_key']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'deduct_amount' in d:
            o.deduct_amount = d['deduct_amount']
        if 'ededuct_product_code' in d:
            o.ededuct_product_code = d['ededuct_product_code']
        if 'execute_date' in d:
            o.execute_date = d['execute_date']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'out_agreement_id' in d:
            o.out_agreement_id = d['out_agreement_id']
        if 'pay_mode' in d:
            o.pay_mode = d['pay_mode']
        if 'service_desc' in d:
            o.service_desc = d['service_desc']
        if 'sub_biz_type' in d:
            o.sub_biz_type = d['sub_biz_type']
        if 'threshold_amount' in d:
            o.threshold_amount = d['threshold_amount']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerversionGrayPublishModel(object):

    def __init__(self):
        self._app_origin = None
        self._app_version = None
        self._beta_app_id_list = None
        self._bundle_id = None
        self._gray_strategy = None
        self._mini_app_id = None
        self._pid = None

    @property
    def app_origin(self):
        return self._app_origin

    @app_origin.setter
    def app_origin(self, value):
        self._app_origin = value
    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def beta_app_id_list(self):
        return self._beta_app_id_list

    @beta_app_id_list.setter
    def beta_app_id_list(self, value):
        if isinstance(value, list):
            self._beta_app_id_list = list()
            for i in value:
                self._beta_app_id_list.append(i)
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value
    @property
    def gray_strategy(self):
        return self._gray_strategy

    @gray_strategy.setter
    def gray_strategy(self, value):
        self._gray_strategy = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def pid(self):
        return self._pid

    @pid.setter
    def pid(self, value):
        self._pid = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_origin:
            if hasattr(self.app_origin, 'to_alipay_dict'):
                params['app_origin'] = self.app_origin.to_alipay_dict()
            else:
                params['app_origin'] = self.app_origin
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.beta_app_id_list:
            if isinstance(self.beta_app_id_list, list):
                for i in range(0, len(self.beta_app_id_list)):
                    element = self.beta_app_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.beta_app_id_list[i] = element.to_alipay_dict()
            if hasattr(self.beta_app_id_list, 'to_alipay_dict'):
                params['beta_app_id_list'] = self.beta_app_id_list.to_alipay_dict()
            else:
                params['beta_app_id_list'] = self.beta_app_id_list
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        if self.gray_strategy:
            if hasattr(self.gray_strategy, 'to_alipay_dict'):
                params['gray_strategy'] = self.gray_strategy.to_alipay_dict()
            else:
                params['gray_strategy'] = self.gray_strategy
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.pid:
            if hasattr(self.pid, 'to_alipay_dict'):
                params['pid'] = self.pid.to_alipay_dict()
            else:
                params['pid'] = self.pid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerversionGrayPublishModel()
        if 'app_origin' in d:
            o.app_origin = d['app_origin']
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'beta_app_id_list' in d:
            o.beta_app_id_list = d['beta_app_id_list']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        if 'gray_strategy' in d:
            o.gray_strategy = d['gray_strategy']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'pid' in d:
            o.pid = d['pid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class FoodDispenserCellInfo(object):

    def __init__(self):
        self._biz_status = None
        self._cell_code = None
        self._cell_name = None
        self._column_no = None
        self._row_no = None

    @property
    def biz_status(self):
        return self._biz_status

    @biz_status.setter
    def biz_status(self, value):
        self._biz_status = value
    @property
    def cell_code(self):
        return self._cell_code

    @cell_code.setter
    def cell_code(self, value):
        self._cell_code = value
    @property
    def cell_name(self):
        return self._cell_name

    @cell_name.setter
    def cell_name(self, value):
        self._cell_name = value
    @property
    def column_no(self):
        return self._column_no

    @column_no.setter
    def column_no(self, value):
        self._column_no = value
    @property
    def row_no(self):
        return self._row_no

    @row_no.setter
    def row_no(self, value):
        self._row_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_status:
            if hasattr(self.biz_status, 'to_alipay_dict'):
                params['biz_status'] = self.biz_status.to_alipay_dict()
            else:
                params['biz_status'] = self.biz_status
        if self.cell_code:
            if hasattr(self.cell_code, 'to_alipay_dict'):
                params['cell_code'] = self.cell_code.to_alipay_dict()
            else:
                params['cell_code'] = self.cell_code
        if self.cell_name:
            if hasattr(self.cell_name, 'to_alipay_dict'):
                params['cell_name'] = self.cell_name.to_alipay_dict()
            else:
                params['cell_name'] = self.cell_name
        if self.column_no:
            if hasattr(self.column_no, 'to_alipay_dict'):
                params['column_no'] = self.column_no.to_alipay_dict()
            else:
                params['column_no'] = self.column_no
        if self.row_no:
            if hasattr(self.row_no, 'to_alipay_dict'):
                params['row_no'] = self.row_no.to_alipay_dict()
            else:
                params['row_no'] = self.row_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = FoodDispenserCellInfo()
        if 'biz_status' in d:
            o.biz_status = d['biz_status']
        if 'cell_code' in d:
            o.cell_code = d['cell_code']
        if 'cell_name' in d:
            o.cell_name = d['cell_name']
        if 'column_no' in d:
            o.column_no = d['column_no']
        if 'row_no' in d:
            o.row_no = d['row_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AlipayAccount import AlipayAccount


class AlipayUserAccountGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAccountGetResponse, self).__init__()
        self._alipay_account = None

    @property
    def alipay_account(self):
        return self._alipay_account

    @alipay_account.setter
    def alipay_account(self, value):
        if isinstance(value, AlipayAccount):
            self._alipay_account = value
        else:
            self._alipay_account = AlipayAccount.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayUserAccountGetResponse, self).parse_response_content(response_content)
        if 'alipay_account' in response:
            self.alipay_account = response['alipay_account']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PeriodRuleParams import PeriodRuleParams


class AlipayUserAgreementTransferModel(object):

    def __init__(self):
        self._agreement_no = None
        self._period_rule_params = None
        self._target_product_code = None

    @property
    def agreement_no(self):
        return self._agreement_no

    @agreement_no.setter
    def agreement_no(self, value):
        self._agreement_no = value
    @property
    def period_rule_params(self):
        return self._period_rule_params

    @period_rule_params.setter
    def period_rule_params(self, value):
        if isinstance(value, PeriodRuleParams):
            self._period_rule_params = value
        else:
            self._period_rule_params = PeriodRuleParams.from_alipay_dict(value)
    @property
    def target_product_code(self):
        return self._target_product_code

    @target_product_code.setter
    def target_product_code(self, value):
        self._target_product_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_no:
            if hasattr(self.agreement_no, 'to_alipay_dict'):
                params['agreement_no'] = self.agreement_no.to_alipay_dict()
            else:
                params['agreement_no'] = self.agreement_no
        if self.period_rule_params:
            if hasattr(self.period_rule_params, 'to_alipay_dict'):
                params['period_rule_params'] = self.period_rule_params.to_alipay_dict()
            else:
                params['period_rule_params'] = self.period_rule_params
        if self.target_product_code:
            if hasattr(self.target_product_code, 'to_alipay_dict'):
                params['target_product_code'] = self.target_product_code.to_alipay_dict()
            else:
                params['target_product_code'] = self.target_product_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayUserAgreementTransferModel()
        if 'agreement_no' in d:
            o.agreement_no = d['agreement_no']
        if 'period_rule_params' in d:
            o.period_rule_params = d['period_rule_params']
        if 'target_product_code' in d:
            o.target_product_code = d['target_product_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherSendRuleDetailModify(object):

    def __init__(self):
        self._natural_person_limit = None
        self._phone_number_limit = None
        self._voucher_quantity_limit_per_user = None

    @property
    def natural_person_limit(self):
        return self._natural_person_limit

    @natural_person_limit.setter
    def natural_person_limit(self, value):
        self._natural_person_limit = value
    @property
    def phone_number_limit(self):
        return self._phone_number_limit

    @phone_number_limit.setter
    def phone_number_limit(self, value):
        self._phone_number_limit = value
    @property
    def voucher_quantity_limit_per_user(self):
        return self._voucher_quantity_limit_per_user

    @voucher_quantity_limit_per_user.setter
    def voucher_quantity_limit_per_user(self, value):
        self._voucher_quantity_limit_per_user = value


    def to_alipay_dict(self):
        params = dict()
        if self.natural_person_limit:
            if hasattr(self.natural_person_limit, 'to_alipay_dict'):
                params['natural_person_limit'] = self.natural_person_limit.to_alipay_dict()
            else:
                params['natural_person_limit'] = self.natural_person_limit
        if self.phone_number_limit:
            if hasattr(self.phone_number_limit, 'to_alipay_dict'):
                params['phone_number_limit'] = self.phone_number_limit.to_alipay_dict()
            else:
                params['phone_number_limit'] = self.phone_number_limit
        if self.voucher_quantity_limit_per_user:
            if hasattr(self.voucher_quantity_limit_per_user, 'to_alipay_dict'):
                params['voucher_quantity_limit_per_user'] = self.voucher_quantity_limit_per_user.to_alipay_dict()
            else:
                params['voucher_quantity_limit_per_user'] = self.voucher_quantity_limit_per_user
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherSendRuleDetailModify()
        if 'natural_person_limit' in d:
            o.natural_person_limit = d['natural_person_limit']
        if 'phone_number_limit' in d:
            o.phone_number_limit = d['phone_number_limit']
        if 'voucher_quantity_limit_per_user' in d:
            o.voucher_quantity_limit_per_user = d['voucher_quantity_limit_per_user']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayTradeOverseasSettleResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeOverseasSettleResponse, self).__init__()
        self._exchange_rate = None
        self._foreign_settle_amount = None
        self._foreign_settle_currency = None
        self._out_request_no = None
        self._settle_amount = None
        self._trade_no = None

    @property
    def exchange_rate(self):
        return self._exchange_rate

    @exchange_rate.setter
    def exchange_rate(self, value):
        self._exchange_rate = value
    @property
    def foreign_settle_amount(self):
        return self._foreign_settle_amount

    @foreign_settle_amount.setter
    def foreign_settle_amount(self, value):
        self._foreign_settle_amount = value
    @property
    def foreign_settle_currency(self):
        return self._foreign_settle_currency

    @foreign_settle_currency.setter
    def foreign_settle_currency(self, value):
        self._foreign_settle_currency = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def settle_amount(self):
        return self._settle_amount

    @settle_amount.setter
    def settle_amount(self, value):
        self._settle_amount = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AlipayTradeOverseasSettleResponse, self).parse_response_content(response_content)
        if 'exchange_rate' in response:
            self.exchange_rate = response['exchange_rate']
        if 'foreign_settle_amount' in response:
            self.foreign_settle_amount = response['foreign_settle_amount']
        if 'foreign_settle_currency' in response:
            self.foreign_settle_currency = response['foreign_settle_currency']
        if 'out_request_no' in response:
            self.out_request_no = response['out_request_no']
        if 'settle_amount' in response:
            self.settle_amount = response['settle_amount']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MaintainBizOrder import MaintainBizOrder


class AlipayEcoMycarMaintainBizorderUpdateModel(object):

    def __init__(self):
        self._appoint_affirm_time = None
        self._appoint_end_time = None
        self._appoint_start_time = None
        self._appoint_status = None
        self._arrive_time = None
        self._order_no = None
        self._order_server_list = None
        self._original_cost = None
        self._out_shop_id = None
        self._real_cost = None
        self._scene_type = None

    @property
    def appoint_affirm_time(self):
        return self._appoint_affirm_time

    @appoint_affirm_time.setter
    def appoint_affirm_time(self, value):
        self._appoint_affirm_time = value
    @property
    def appoint_end_time(self):
        return self._appoint_end_time

    @appoint_end_time.setter
    def appoint_end_time(self, value):
        self._appoint_end_time = value
    @property
    def appoint_start_time(self):
        return self._appoint_start_time

    @appoint_start_time.setter
    def appoint_start_time(self, value):
        self._appoint_start_time = value
    @property
    def appoint_status(self):
        return self._appoint_status

    @appoint_status.setter
    def appoint_status(self, value):
        self._appoint_status = value
    @property
    def arrive_time(self):
        return self._arrive_time

    @arrive_time.setter
    def arrive_time(self, value):
        self._arrive_time = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def order_server_list(self):
        return self._order_server_list

    @order_server_list.setter
    def order_server_list(self, value):
        if isinstance(value, list):
            self._order_server_list = list()
            for i in value:
                if isinstance(i, MaintainBizOrder):
                    self._order_server_list.append(i)
                else:
                    self._order_server_list.append(MaintainBizOrder.from_alipay_dict(i))
    @property
    def original_cost(self):
        return self._original_cost

    @original_cost.setter
    def original_cost(self, value):
        self._original_cost = value
    @property
    def out_shop_id(self):
        return self._out_shop_id

    @out_shop_id.setter
    def out_shop_id(self, value):
        self._out_shop_id = value
    @property
    def real_cost(self):
        return self._real_cost

    @real_cost.setter
    def real_cost(self, value):
        self._real_cost = value
    @property
    def scene_type(self):
        return self._scene_type

    @scene_type.setter
    def scene_type(self, value):
        self._scene_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.appoint_affirm_time:
            if hasattr(self.appoint_affirm_time, 'to_alipay_dict'):
                params['appoint_affirm_time'] = self.appoint_affirm_time.to_alipay_dict()
            else:
                params['appoint_affirm_time'] = self.appoint_affirm_time
        if self.appoint_end_time:
            if hasattr(self.appoint_end_time, 'to_alipay_dict'):
                params['appoint_end_time'] = self.appoint_end_time.to_alipay_dict()
            else:
                params['appoint_end_time'] = self.appoint_end_time
        if self.appoint_start_time:
            if hasattr(self.appoint_start_time, 'to_alipay_dict'):
                params['appoint_start_time'] = self.appoint_start_time.to_alipay_dict()
            else:
                params['appoint_start_time'] = self.appoint_start_time
        if self.appoint_status:
            if hasattr(self.appoint_status, 'to_alipay_dict'):
                params['appoint_status'] = self.appoint_status.to_alipay_dict()
            else:
                params['appoint_status'] = self.appoint_status
        if self.arrive_time:
            if hasattr(self.arrive_time, 'to_alipay_dict'):
                params['arrive_time'] = self.arrive_time.to_alipay_dict()
            else:
                params['arrive_time'] = self.arrive_time
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.order_server_list:
            if isinstance(self.order_server_list, list):
                for i in range(0, len(self.order_server_list)):
                    element = self.order_server_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.order_server_list[i] = element.to_alipay_dict()
            if hasattr(self.order_server_list, 'to_alipay_dict'):
                params['order_server_list'] = self.order_server_list.to_alipay_dict()
            else:
                params['order_server_list'] = self.order_server_list
        if self.original_cost:
            if hasattr(self.original_cost, 'to_alipay_dict'):
                params['original_cost'] = self.original_cost.to_alipay_dict()
            else:
                params['original_cost'] = self.original_cost
        if self.out_shop_id:
            if hasattr(self.out_shop_id, 'to_alipay_dict'):
                params['out_shop_id'] = self.out_shop_id.to_alipay_dict()
            else:
                params['out_shop_id'] = self.out_shop_id
        if self.real_cost:
            if hasattr(self.real_cost, 'to_alipay_dict'):
                params['real_cost'] = self.real_cost.to_alipay_dict()
            else:
                params['real_cost'] = self.real_cost
        if self.scene_type:
            if hasattr(self.scene_type, 'to_alipay_dict'):
                params['scene_type'] = self.scene_type.to_alipay_dict()
            else:
                params['scene_type'] = self.scene_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarMaintainBizorderUpdateModel()
        if 'appoint_affirm_time' in d:
            o.appoint_affirm_time = d['appoint_affirm_time']
        if 'appoint_end_time' in d:
            o.appoint_end_time = d['appoint_end_time']
        if 'appoint_start_time' in d:
            o.appoint_start_time = d['appoint_start_time']
        if 'appoint_status' in d:
            o.appoint_status = d['appoint_status']
        if 'arrive_time' in d:
            o.arrive_time = d['arrive_time']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'order_server_list' in d:
            o.order_server_list = d['order_server_list']
        if 'original_cost' in d:
            o.original_cost = d['original_cost']
        if 'out_shop_id' in d:
            o.out_shop_id = d['out_shop_id']
        if 'real_cost' in d:
            o.real_cost = d['real_cost']
        if 'scene_type' in d:
            o.scene_type = d['scene_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AdCreative import AdCreative


class AlipayCommerceTransportAdCreativeCreateModel(object):

    def __init__(self):
        self._ad_creative = None
        self._ad_user_id = None

    @property
    def ad_creative(self):
        return self._ad_creative

    @ad_creative.setter
    def ad_creative(self, value):
        if isinstance(value, AdCreative):
            self._ad_creative = value
        else:
            self._ad_creative = AdCreative.from_alipay_dict(value)
    @property
    def ad_user_id(self):
        return self._ad_user_id

    @ad_user_id.setter
    def ad_user_id(self, value):
        self._ad_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.ad_creative:
            if hasattr(self.ad_creative, 'to_alipay_dict'):
                params['ad_creative'] = self.ad_creative.to_alipay_dict()
            else:
                params['ad_creative'] = self.ad_creative
        if self.ad_user_id:
            if hasattr(self.ad_user_id, 'to_alipay_dict'):
                params['ad_user_id'] = self.ad_user_id.to_alipay_dict()
            else:
                params['ad_user_id'] = self.ad_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportAdCreativeCreateModel()
        if 'ad_creative' in d:
            o.ad_creative = d['ad_creative']
        if 'ad_user_id' in d:
            o.ad_user_id = d['ad_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.PayContractBaseDTO import PayContractBaseDTO


class AlipayBossFncGfsettlePaycontractQueryModel(object):

    def __init__(self):
        self._pay_contract_base_dto = None

    @property
    def pay_contract_base_dto(self):
        return self._pay_contract_base_dto

    @pay_contract_base_dto.setter
    def pay_contract_base_dto(self, value):
        if isinstance(value, PayContractBaseDTO):
            self._pay_contract_base_dto = value
        else:
            self._pay_contract_base_dto = PayContractBaseDTO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.pay_contract_base_dto:
            if hasattr(self.pay_contract_base_dto, 'to_alipay_dict'):
                params['pay_contract_base_dto'] = self.pay_contract_base_dto.to_alipay_dict()
            else:
                params['pay_contract_base_dto'] = self.pay_contract_base_dto
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettlePaycontractQueryModel()
        if 'pay_contract_base_dto' in d:
            o.pay_contract_base_dto = d['pay_contract_base_dto']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ReceiverAddressInfo(object):

    def __init__(self):
        self._address = None
        self._division_code = None
        self._mobile = None
        self._name = None
        self._zip = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def division_code(self):
        return self._division_code

    @division_code.setter
    def division_code(self, value):
        self._division_code = value
    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def zip(self):
        return self._zip

    @zip.setter
    def zip(self, value):
        self._zip = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.division_code:
            if hasattr(self.division_code, 'to_alipay_dict'):
                params['division_code'] = self.division_code.to_alipay_dict()
            else:
                params['division_code'] = self.division_code
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.zip:
            if hasattr(self.zip, 'to_alipay_dict'):
                params['zip'] = self.zip.to_alipay_dict()
            else:
                params['zip'] = self.zip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReceiverAddressInfo()
        if 'address' in d:
            o.address = d['address']
        if 'division_code' in d:
            o.division_code = d['division_code']
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'name' in d:
            o.name = d['name']
        if 'zip' in d:
            o.zip = d['zip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayTradeRepaybillQueryModel(object):

    def __init__(self):
        self._bill_no = None
        self._bill_product = None
        self._out_bill_no = None
        self._user_id = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_product(self):
        return self._bill_product

    @bill_product.setter
    def bill_product(self, value):
        self._bill_product = value
    @property
    def out_bill_no(self):
        return self._out_bill_no

    @out_bill_no.setter
    def out_bill_no(self, value):
        self._out_bill_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.bill_product:
            if hasattr(self.bill_product, 'to_alipay_dict'):
                params['bill_product'] = self.bill_product.to_alipay_dict()
            else:
                params['bill_product'] = self.bill_product
        if self.out_bill_no:
            if hasattr(self.out_bill_no, 'to_alipay_dict'):
                params['out_bill_no'] = self.out_bill_no.to_alipay_dict()
            else:
                params['out_bill_no'] = self.out_bill_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayTradeRepaybillQueryModel()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'bill_product' in d:
            o.bill_product = d['bill_product']
        if 'out_bill_no' in d:
            o.out_bill_no = d['out_bill_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossFncGfsettleprodBillinvoiceQueryModel(object):

    def __init__(self):
        self._apply_relative_id = None
        self._bill_no = None
        self._seller_ip_role_id = None

    @property
    def apply_relative_id(self):
        return self._apply_relative_id

    @apply_relative_id.setter
    def apply_relative_id(self, value):
        self._apply_relative_id = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def seller_ip_role_id(self):
        return self._seller_ip_role_id

    @seller_ip_role_id.setter
    def seller_ip_role_id(self, value):
        self._seller_ip_role_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.apply_relative_id:
            if hasattr(self.apply_relative_id, 'to_alipay_dict'):
                params['apply_relative_id'] = self.apply_relative_id.to_alipay_dict()
            else:
                params['apply_relative_id'] = self.apply_relative_id
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.seller_ip_role_id:
            if hasattr(self.seller_ip_role_id, 'to_alipay_dict'):
                params['seller_ip_role_id'] = self.seller_ip_role_id.to_alipay_dict()
            else:
                params['seller_ip_role_id'] = self.seller_ip_role_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossFncGfsettleprodBillinvoiceQueryModel()
        if 'apply_relative_id' in d:
            o.apply_relative_id = d['apply_relative_id']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'seller_ip_role_id' in d:
            o.seller_ip_role_id = d['seller_ip_role_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AlipayInsDataDsbRequestImageInfo import AlipayInsDataDsbRequestImageInfo


class AlipayInsDataDsbEstimateApplyModel(object):

    def __init__(self):
        self._accident_area_id = None
        self._car_properties = None
        self._case_properties = None
        self._commercial_policy_no = None
        self._compulsory_policy_no = None
        self._engine_no = None
        self._estimate_no = None
        self._estimate_request_uuid = None
        self._frame_no = None
        self._garage_type = None
        self._image_list = None
        self._license_no = None
        self._model_brand = None
        self._new_car_price = None
        self._repair_corp_properties = None
        self._report_no = None
        self._request_timestamp = None
        self._survey_no = None

    @property
    def accident_area_id(self):
        return self._accident_area_id

    @accident_area_id.setter
    def accident_area_id(self, value):
        self._accident_area_id = value
    @property
    def car_properties(self):
        return self._car_properties

    @car_properties.setter
    def car_properties(self, value):
        self._car_properties = value
    @property
    def case_properties(self):
        return self._case_properties

    @case_properties.setter
    def case_properties(self, value):
        self._case_properties = value
    @property
    def commercial_policy_no(self):
        return self._commercial_policy_no

    @commercial_policy_no.setter
    def commercial_policy_no(self, value):
        self._commercial_policy_no = value
    @property
    def compulsory_policy_no(self):
        return self._compulsory_policy_no

    @compulsory_policy_no.setter
    def compulsory_policy_no(self, value):
        self._compulsory_policy_no = value
    @property
    def engine_no(self):
        return self._engine_no

    @engine_no.setter
    def engine_no(self, value):
        self._engine_no = value
    @property
    def estimate_no(self):
        return self._estimate_no

    @estimate_no.setter
    def estimate_no(self, value):
        self._estimate_no = value
    @property
    def estimate_request_uuid(self):
        return self._estimate_request_uuid

    @estimate_request_uuid.setter
    def estimate_request_uuid(self, value):
        self._estimate_request_uuid = value
    @property
    def frame_no(self):
        return self._frame_no

    @frame_no.setter
    def frame_no(self, value):
        self._frame_no = value
    @property
    def garage_type(self):
        return self._garage_type

    @garage_type.setter
    def garage_type(self, value):
        self._garage_type = value
    @property
    def image_list(self):
        return self._image_list

    @image_list.setter
    def image_list(self, value):
        if isinstance(value, list):
            self._image_list = list()
            for i in value:
                if isinstance(i, AlipayInsDataDsbRequestImageInfo):
                    self._image_list.append(i)
                else:
                    self._image_list.append(AlipayInsDataDsbRequestImageInfo.from_alipay_dict(i))
    @property
    def license_no(self):
        return self._license_no

    @license_no.setter
    def license_no(self, value):
        self._license_no = value
    @property
    def model_brand(self):
        return self._model_brand

    @model_brand.setter
    def model_brand(self, value):
        self._model_brand = value
    @property
    def new_car_price(self):
        return self._new_car_price

    @new_car_price.setter
    def new_car_price(self, value):
        self._new_car_price = value
    @property
    def repair_corp_properties(self):
        return self._repair_corp_properties

    @repair_corp_properties.setter
    def repair_corp_properties(self, value):
        self._repair_corp_properties = value
    @property
    def report_no(self):
        return self._report_no

    @report_no.setter
    def report_no(self, value):
        self._report_no = value
    @property
    def request_timestamp(self):
        return self._request_timestamp

    @request_timestamp.setter
    def request_timestamp(self, value):
        self._request_timestamp = value
    @property
    def survey_no(self):
        return self._survey_no

    @survey_no.setter
    def survey_no(self, value):
        self._survey_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.accident_area_id:
            if hasattr(self.accident_area_id, 'to_alipay_dict'):
                params['accident_area_id'] = self.accident_area_id.to_alipay_dict()
            else:
                params['accident_area_id'] = self.accident_area_id
        if self.car_properties:
            if hasattr(self.car_properties, 'to_alipay_dict'):
                params['car_properties'] = self.car_properties.to_alipay_dict()
            else:
                params['car_properties'] = self.car_properties
        if self.case_properties:
            if hasattr(self.case_properties, 'to_alipay_dict'):
                params['case_properties'] = self.case_properties.to_alipay_dict()
            else:
                params['case_properties'] = self.case_properties
        if self.commercial_policy_no:
            if hasattr(self.commercial_policy_no, 'to_alipay_dict'):
                params['commercial_policy_no'] = self.commercial_policy_no.to_alipay_dict()
            else:
                params['commercial_policy_no'] = self.commercial_policy_no
        if self.compulsory_policy_no:
            if hasattr(self.compulsory_policy_no, 'to_alipay_dict'):
                params['compulsory_policy_no'] = self.compulsory_policy_no.to_alipay_dict()
            else:
                params['compulsory_policy_no'] = self.compulsory_policy_no
        if self.engine_no:
            if hasattr(self.engine_no, 'to_alipay_dict'):
                params['engine_no'] = self.engine_no.to_alipay_dict()
            else:
                params['engine_no'] = self.engine_no
        if self.estimate_no:
            if hasattr(self.estimate_no, 'to_alipay_dict'):
                params['estimate_no'] = self.estimate_no.to_alipay_dict()
            else:
                params['estimate_no'] = self.estimate_no
        if self.estimate_request_uuid:
            if hasattr(self.estimate_request_uuid, 'to_alipay_dict'):
                params['estimate_request_uuid'] = self.estimate_request_uuid.to_alipay_dict()
            else:
                params['estimate_request_uuid'] = self.estimate_request_uuid
        if self.frame_no:
            if hasattr(self.frame_no, 'to_alipay_dict'):
                params['frame_no'] = self.frame_no.to_alipay_dict()
            else:
                params['frame_no'] = self.frame_no
        if self.garage_type:
            if hasattr(self.garage_type, 'to_alipay_dict'):
                params['garage_type'] = self.garage_type.to_alipay_dict()
            else:
                params['garage_type'] = self.garage_type
        if self.image_list:
            if isinstance(self.image_list, list):
                for i in range(0, len(self.image_list)):
                    element = self.image_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.image_list[i] = element.to_alipay_dict()
            if hasattr(self.image_list, 'to_alipay_dict'):
                params['image_list'] = self.image_list.to_alipay_dict()
            else:
                params['image_list'] = self.image_list
        if self.license_no:
            if hasattr(self.license_no, 'to_alipay_dict'):
                params['license_no'] = self.license_no.to_alipay_dict()
            else:
                params['license_no'] = self.license_no
        if self.model_brand:
            if hasattr(self.model_brand, 'to_alipay_dict'):
                params['model_brand'] = self.model_brand.to_alipay_dict()
            else:
                params['model_brand'] = self.model_brand
        if self.new_car_price:
            if hasattr(self.new_car_price, 'to_alipay_dict'):
                params['new_car_price'] = self.new_car_price.to_alipay_dict()
            else:
                params['new_car_price'] = self.new_car_price
        if self.repair_corp_properties:
            if hasattr(self.repair_corp_properties, 'to_alipay_dict'):
                params['repair_corp_properties'] = self.repair_corp_properties.to_alipay_dict()
            else:
                params['repair_corp_properties'] = self.repair_corp_properties
        if self.report_no:
            if hasattr(self.report_no, 'to_alipay_dict'):
                params['report_no'] = self.report_no.to_alipay_dict()
            else:
                params['report_no'] = self.report_no
        if self.request_timestamp:
            if hasattr(self.request_timestamp, 'to_alipay_dict'):
                params['request_timestamp'] = self.request_timestamp.to_alipay_dict()
            else:
                params['request_timestamp'] = self.request_timestamp
        if self.survey_no:
            if hasattr(self.survey_no, 'to_alipay_dict'):
                params['survey_no'] = self.survey_no.to_alipay_dict()
            else:
                params['survey_no'] = self.survey_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsDataDsbEstimateApplyModel()
        if 'accident_area_id' in d:
            o.accident_area_id = d['accident_area_id']
        if 'car_properties' in d:
            o.car_properties = d['car_properties']
        if 'case_properties' in d:
            o.case_properties = d['case_properties']
        if 'commercial_policy_no' in d:
            o.commercial_policy_no = d['commercial_policy_no']
        if 'compulsory_policy_no' in d:
            o.compulsory_policy_no = d['compulsory_policy_no']
        if 'engine_no' in d:
            o.engine_no = d['engine_no']
        if 'estimate_no' in d:
            o.estimate_no = d['estimate_no']
        if 'estimate_request_uuid' in d:
            o.estimate_request_uuid = d['estimate_request_uuid']
        if 'frame_no' in d:
            o.frame_no = d['frame_no']
        if 'garage_type' in d:
            o.garage_type = d['garage_type']
        if 'image_list' in d:
            o.image_list = d['image_list']
        if 'license_no' in d:
            o.license_no = d['license_no']
        if 'model_brand' in d:
            o.model_brand = d['model_brand']
        if 'new_car_price' in d:
            o.new_car_price = d['new_car_price']
        if 'repair_corp_properties' in d:
            o.repair_corp_properties = d['repair_corp_properties']
        if 'report_no' in d:
            o.report_no = d['report_no']
        if 'request_timestamp' in d:
            o.request_timestamp = d['request_timestamp']
        if 'survey_no' in d:
            o.survey_no = d['survey_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenPublicTemplateMessageAddResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenPublicTemplateMessageAddResponse, self).__init__()
        self._template = None
        self._template_id = None

    @property
    def template(self):
        return self._template

    @template.setter
    def template(self, value):
        self._template = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenPublicTemplateMessageAddResponse, self).parse_response_content(response_content)
        if 'template' in response:
            self.template = response['template']
        if 'template_id' in response:
            self.template_id = response['template_id']
